<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">

<xsl:template match="*">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="@*">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="@xpml-id|@xpml-value|@xpml-copy" priority="1"/>

<xsl:template match="*[@xpml-id != '' and contains(@xpml-id, '#')]" priority="1">
  <xsl:variable name="index" select="substring-before(@xpml-id, '#')"/>
  <xsl:element name="{name()}">
    <xsl:attribute name="ref"><xsl:value-of select="@xpml-id"/></xsl:attribute>
    <xsl:apply-templates select="@*[name() != 'ref' and name() != 'xpml-id']"/>
    <xsl:choose>
      <xsl:when test="contains(substring-after(@xpml-id, '#'), '.')">
        <xsl:value-of select="document(@xpml-id)/*"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($index, '#')"/>
        <xsl:value-of select="document(@xpml-id)/*[name() != 'xpml']/@id"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:element>
</xsl:template>

<xsl:template match="*[@xpml-copy != '' and contains(@xpml-copy, '#')]" priority="1">
  <xsl:variable name="index" select="substring-before(@xpml-copy, '#')"/>
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*[name() != 'ref' and name() != 'xpml-copy']"/>
    <xsl:attribute name="ref"><xsl:value-of select="@xpml-copy"/></xsl:attribute>
    <xsl:for-each select="document(@xpml-copy)/*[name() != 'xpml']">
      <xsl:apply-templates select="*[name() != 'xpml']"/>
    </xsl:for-each>
  </xsl:element>
</xsl:template>

<xsl:template match="*[@xpml-value != '' and contains(@xpml-value, '#')]" priority="1">
  <xsl:variable name="index" select="substring-before(@xpml-value, '#')"/>
  <xsl:element name="{name()}">
    <xsl:attribute name="ref"><xsl:value-of select="@xpml-value"/></xsl:attribute>
    <xsl:apply-templates select="@*[name() != 'ref' and name() != 'xpml-value']"/>
    <xsl:for-each select="document(@xpml-value)/*[name() != 'xpml']">
      <xsl:value-of select="normalize-space(text())"/>
      <xsl:if test="normalize-space(text()) = ''"><xsl:value-of select="normalize-space(*[1])"/></xsl:if>
    </xsl:for-each>
  </xsl:element>
</xsl:template>

<xsl:template match="*[@xpml-file != '']" priority="1">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*[not(name() = 'xpml-file')]"/>
    <xsl:attribute name="ref-src"><xsl:value-of select="@xpml-file"/></xsl:attribute>
    <xsl:apply-templates select="$xpml/resource//*[@ref-src = current()/@xpml-file]/*"/>
    <xsl:apply-templates select="*"/>
  </xsl:element>
</xsl:template>

<xsl:template match="*[@xpml-import-upload-file != '']" priority="1">
  <xsl:variable name="files"><xsl:copy-of select="$request/files/*"/></xsl:variable>
  <xsl:variable name="name" select="@xpml-import-upload-file"/>
  <xsl:variable name="position" select="@xpml-import-upload-file"/>
  <xsl:variable name="multiple-names">
    <xsl:if test="count($files/*) &gt; 1">-<xsl:value-of select="substring-after($name, '-')"/></xsl:if>
  </xsl:variable>
  <xsl:choose>
    <xsl:when test="$files/*[name() = $name]/size &gt; 0">
      <xsl:element name="{name()}">
        <xsl:attribute name="ref-src"><xsl:value-of select="concat($xpml-identifier, ':', translate($date, '-T:', ''), $multiple-names, '-', $files/*[name() = $name]/name)"/></xsl:attribute>
        <xsl:apply-templates select="@*[not(name() = 'xpml-import-upload-file')]"/>
        <xsl:for-each select="$files/*[name() = $name]/*">
          <xsl:choose>
            <xsl:when test="name() = 'type'"><format><xsl:value-of select="."/></format></xsl:when>
            <xsl:when test="name() != 'tmp_name'">
              <xsl:element name="{name()}">
                <xsl:value-of select="."/>
              </xsl:element>
            </xsl:when>
          </xsl:choose>
        </xsl:for-each>
        <date type="modified"><xsl:value-of select="$date"/></date>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:variable name="ref">
        <xsl:element name="{name()}">
          <xsl:copy-of select="@*[not(name() = 'xpml-import-upload-file')]"/>
          <xsl:copy-of select="*|text()" />
        </xsl:element>
      </xsl:variable>
      <xsl:apply-templates select="$ref/*"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>