<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml" omit-xml-declaration="yes"/>

<xsl:include href="dav_header.xsl"/>
<xsl:include href="dav_meta.xsl"/>
<xsl:include href="dav_version.xsl"/>
<xsl:include href="dav_components.xsl"/>
<xsl:variable name="custom-datasets"><xsl:copy-of select="document('index:datasets')/xpml/resource[@type='component-structure' and contains(@meta-types, $xpml/meta/type)]"/></xsl:variable>

<xsl:template match="/">
<xsl:if test="count($xpml/*) = 0"><xsl:message terminate="yes"><xsl:value-of select="$labels/error/file_invalid"/></xsl:message></xsl:if>
<html>
  <head>
    <xsl:apply-templates select="xpml/meta" mode="header"/>
    <link rel="stylesheet" href="{$base}/dav/styles/calendar-blue.css" type="text/css" />
    <link rel="stylesheet" href="{$base}/dav/styles/htmlarea.css" type="text/css" />
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/calendar.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/htmlarea.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/{$language}.js"><xsl:text> </xsl:text></script>
  </head>
  <body>
    <xsl:if test="$users/user[@id = $user]/wysiwyg-editor">
      <xsl:attribute name="onload">xInit();initAllEditor(document.dav)</xsl:attribute>
    </xsl:if>
    <xsl:if test="$msg != ''"><p class="msg"><xsl:value-of select="$msg" disable-output-escaping="yes" /></p></xsl:if>
    <xsl:call-template name="header"/>
    <form id="dav" name="dav" submit-encoding="iso-8859-1" method="post" enctype="multipart/form-data">
      <xsl:choose>
        <xsl:when test="normalize-space($read-only) = 'all'">
          <xsl:attribute name="action">#</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="action"><xsl:value-of select="$action"/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <div id="hidden-data" name="hidden-data" class="invisible">
          <input type="hidden" name="dav-id" value="{$dav-id}" />
      </div>
      <div id="col123">
        <table cellpadding="0" cellspacing="0" border="0" width="100%">
          <tbody>
          <tr>
            <td width="33%" class="first">
              <xsl:apply-templates select="$xpml/meta"/>
              <xsl:apply-templates select="$xpml/meta" mode="version-control"/>
            </td>
            <td width="67%" class="first">
              <xsl:apply-templates select="xpml" mode="options"/>
              <xsl:apply-templates select="/" mode="resources"/>
              <xsl:apply-templates select="xpml/meta" mode="buttons"/>
            </td>
          </tr>
          </tbody>
        </table>
      </div>
    </form>
    <div class="invisible">
      <xsl:apply-templates select="$xpml/meta" mode="meta-hidden"/>
      <xsl:for-each select="$xpml/resource[@type='binary']">
        <xsl:variable name="position" select="count(preceding-sibling::resource) + 1"/>
        <xsl:variable name="e" select="concat('x[', $position, '][resource]')"/>
        <div id="file-{$position}" name="file-{$position}">
          <input type="hidden" name="{$e}[@import-upload-file]" value="{resource-description/@ref}"/>
        </div>
      </xsl:for-each>
    </div>
  </body>
</html>
</xsl:template>

<xsl:template match="xpml" mode="options">
  <h3>
    <xsl:value-of select="$labels/content/edit"/>
    <xsl:if test="contains($request/get/id, '.')">&#160;<xsl:value-of select="$labels/content/copy"/></xsl:if>
  </h3>
  <xsl:if test="count(resource/*) &gt; 0">
    <p>
      <xsl:apply-templates select="resource" mode="content-listing"/>
      <xsl:apply-templates select="$request/get/new" mode="content-listing"/>
    </p>
  </xsl:if>
  <div class="options">
    <xsl:if test="not(normalize-space($read-only)= 'all') and not($request/get/merge != '')">
      <label for="goto"><xsl:value-of select="$labels/buttons/new"/></label><br />
      <select name="goto" id="goto" class="textinput" style="width:27%;margin-right:10px">
        <xsl:for-each select="$custom-datasets/*">
          <option value="{@name}"><xsl:value-of select="title"/></option>
        </xsl:for-each>
      </select>
      <input type="button" class="submitinput" value="{$labels/buttons/insert}" onclick="document.dav.action='{$action}&amp;new='+document.dav.elements['goto'].value+'#{count(resource) +1}';pin_send(document.dav);" />
    </xsl:if>
    <xsl:if test="$request/get/merge != ''">
      <p><strong><xsl:value-of select="$labels/versions/merge"/></strong><br /><xsl:value-of select="$labels/versions/instructions"/> "<xsl:value-of select="$labels/buttons/save_merge"/>".</p>
    </xsl:if>
  </div>
</xsl:template>

<xsl:template match="meta" mode="buttons">
  <div style="width:90%">
    <xsl:if test="not(normalize-space($read-only) = 'all')">
      <xsl:choose>
        <xsl:when test="not($request/get/merge != '')">
          <input class="submitinput" type="button" value="{$labels/buttons/save}"  accesskey="s" onclick="pin_send(document.dav)" />
        </xsl:when>
        <xsl:otherwise>
          <input class="submitinput" type="button" value="{$labels/buttons/save_merge}"  accesskey="s" onclick="document.dav.action = '{$action}&amp;merge={$request/get/merge}';pin_send(document.dav)" />
          <input class="submitinput" type="button" value="{$labels/buttons/dont_merge}" onclick="window.location.href='{$action}';" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
    <input class="submitinput" type="button" value="{$labels/buttons/save_copy}" onclick="document.dav['dav-id'].value='';document.dav.action = '{$script-name}?id={$request/get/id}.{$next-version}&amp;copy=1';pin_send(document.dav)" />
    <xsl:if test="identifier[@type='url'] != ''">
      <input class="submitinput" type="button" value="{$labels/buttons/publish}" accesskey="e" onclick="window.location.href='{$action}&amp;close=1&amp;url={$base}/publish.dav?ids={$request/get/id}';" />
    </xsl:if>
    <input class="submitinput" type="button" value="{$labels/buttons/close}" accesskey="w" onclick="window.location.href='{$action}&amp;close=1&amp;url={$xpml/meta/identifier[@type='url']}';" />
    <xsl:if test="not(normalize-space($read-only) = 'all') and not(contains($request/get/id, '.'))">
      <input class="submitinput" type="button" value="{$labels/buttons/delete}" onclick="doc_delete(document.dav)" style="margin-right: 0px;" />
    </xsl:if>
    <xsl:if test="not(normalize-space($read-only) = 'all') and contains($request/get/id, '.')">
      <input class="submitinput" type="button" value="{$labels/buttons/delete_copy}" onclick="doc_delete(document.dav)" style="margin-right: 0px;" />
    </xsl:if>
  </div>
</xsl:template>


<xsl:template match="/" mode="resources">
  <div class="dataset">
  <xsl:apply-templates select="$xpml/resource" mode="content"/>
  <xsl:apply-templates select="$request/get/new"/>
  </div>
</xsl:template>

<xsl:template match="resource" mode="content">
  <xsl:param name="position" select="count(preceding-sibling::resource) + 1"/>
  <xsl:variable name="e" select="concat('x[', $position, '][resource]')"/>
  <xsl:variable name="id" select="concat(substring-before(@id, '#'), '#', $position)"/>
  <xsl:variable name="ref" select="."/>
  <div id="{$position}" name="{$position}" class="content">
    <p>
      <xsl:value-of select="$position"/>: <xsl:value-of select="$custom-datasets/resource[@name=current()/@type and @type='component-structure']/title"/>
      <xsl:if test="$position &gt; 1 and not(normalize-space($read-only)= 'all') and not(contains($read-only, 'resource-content '))"><xsl:text> </xsl:text><a href="#" style="text-decoration: none;" onclick="pin_swap_position('{$position}', '{$position -1}');"><img src="{$base}/dav/images/goup.gif" width="15" height="18" alt="{$labels/content/goup}" border="0" style="vertical-align: middle;" /></a></xsl:if>
      <xsl:if test="not(contains($read-only, 'resource-content ')) and not(normalize-space($read-only)= 'all')">
      <xsl:text>&#160;</xsl:text><a href="#" onclick="pin_todo.action='delete';pin_todo.param='{$e}';pin_send(document.dav);"><img src="{$base}/dav/images/delete.gif" width="10" height="10" alt="{$labels/content/delete}" border="0" style="vertical-align: middle;" /></a>
      </xsl:if>
      <input type="hidden" name="{$e}[@type]" value="{@type}"/>
      <input type="hidden" name="{$e}[@id]" value="{$id}"/>
    </p>
    <xsl:apply-templates select="$custom-datasets/resource[@name=current()/@type and @type='component-structure']/ref" mode="dataset-editing">
      <xsl:with-param name="ref" select="$ref"/>
      <xsl:with-param name="e" select="$e"/>
      <xsl:with-param name="pos" select="$position"/>
    </xsl:apply-templates>
  </div>
  <br />
</xsl:template>

<xsl:template match="resource" mode="content-listing">
  <xsl:param name="position" select="count(preceding-sibling::resource) + 1"/>
  <a href="#{$position}"><xsl:value-of select="$position"/>: <xsl:value-of select="$custom-datasets/resource[@name=current()/@type and @type='component-structure']/title"/></a>
  <xsl:if test="name"> (<xsl:value-of select="name"/>)</xsl:if>
  <xsl:if test="title"> (<xsl:value-of select="title"/>)</xsl:if>
  <br />
</xsl:template>

<xsl:template mode="filesize" match="*|text()">
<xsl:choose>
  <xsl:when test=". &gt; 1048576">
    <xsl:value-of select="format-number((. div 1048576),'#,#')"/>
    <xsl:text> Mb</xsl:text>
  </xsl:when>
  <xsl:when test=". &gt; 1024">
    <xsl:value-of select="round(. div 1024)"/>
    <xsl:text> Kb</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:value-of select="."/>
    <xsl:text> bytes</xsl:text>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="new" mode="content-listing">
  <xsl:variable name="type" select="."/>
  <xsl:variable name="position" select="count($xpml/resource) +1"/>
  <xsl:variable name="defaults">
    <resource id="{$xpml/meta/identifier[@type='id']}#{$position}" type="{$type}">
    </resource>
  </xsl:variable>
  <xsl:apply-templates select="$defaults/*" mode="content-listing">
    <xsl:with-param name="position" select="$position"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="new">
  <xsl:variable name="type" select="."/>
  <xsl:variable name="position" select="count($xpml/resource) +1"/>
  <xsl:variable name="defaults">
    <resource id="{$xpml/meta/identifier[@type='id']}#{$position}" type="{$type}">
      <xsl:for-each select="$custom-datasets/resource[@name=$type]/ref/field">
        <xsl:element name="{name}"></xsl:element>
      </xsl:for-each>
    </resource>
  </xsl:variable>
  <xsl:apply-templates select="$defaults/*" mode="content">
    <xsl:with-param name="position" select="$position"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="new[ . = 'content']">
  <xsl:variable name="type" select="."/>
  <xsl:variable name="position" select="count($xpml/resource) +1"/>
  <xsl:apply-templates select="$default-content" mode="content">
    <xsl:with-param name="position" select="$position"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="new[ . = 'binary']">
  <xsl:variable name="type" select="."/>
  <xsl:variable name="position" select="count($xpml/resource) +1"/>
  <xsl:apply-templates select="$default-binary" mode="content">
    <xsl:with-param name="position" select="$position"/>
    <xsl:with-param name="upload" select="true()"/>
  </xsl:apply-templates>
</xsl:template>

</xsl:stylesheet>