<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml" omit-xml-declaration="yes"/>

<xsl:template match="fieldset" mode="dataset-editing">
  <xsl:param name="ref"><empty/></xsl:param>
  <xsl:param name="e" select="'dataset[ref]'"/>
  <xsl:param name="pos" select="1"/>
  <fieldset>
    <legend><xsl:value-of select="legend"/></legend>
    <xsl:apply-templates select="fieldset|field|inline" mode="dataset-editing">
      <xsl:with-param name="ref" select="$ref"/>
      <xsl:with-param name="e" select="$e"/>
      <xsl:with-param name="pos" select="$pos"/>
    </xsl:apply-templates>
  </fieldset>
</xsl:template>

<xsl:template match="inline" mode="dataset-editing">
  <xsl:param name="ref"><empty/></xsl:param>
  <xsl:param name="e" select="'dataset[ref]'"/>
  <xsl:param name="pos" select="1"/>
  <table cellpadding="0" cellspacing="0" border="0" width="100%">
    <tr>
      <xsl:variable name="width" select="concat(round(100 div count(fieldset|field|inline)), '%')"/>
      <xsl:for-each select="fieldset|field|inline">
        <td width="{$width}">
          <xsl:choose>
            <xsl:when test="position()=1"><xsl:attribute name="class">first</xsl:attribute></xsl:when>
            <xsl:when test="position()=last()"><xsl:attribute name="class">last</xsl:attribute></xsl:when>
          </xsl:choose>
          <xsl:apply-templates select="." mode="dataset-editing">
            <xsl:with-param name="ref" select="$ref"/>
            <xsl:with-param name="e" select="$e"/>
            <xsl:with-param name="pos" select="$pos"/>
          </xsl:apply-templates>
        </td>
      </xsl:for-each>
    </tr>
  </table>
</xsl:template>

<xsl:template match="field" mode="dataset-editing"/>

<xsl:template match="field[@multiple='yes']" mode="dataset-editing" priority="1">
  <xsl:param name="ref"><empty/></xsl:param>
  <xsl:param name="e" select="'dataset[ref]'"/>
  <xsl:param name="pos" select="1"/>
  <xsl:variable name="field">
    <field><xsl:copy-of select="@*[name() != 'multiple']|*|text()"/></field>
  </xsl:variable>
  <xsl:for-each select="$ref/*[name() = current()/name][normalize-space(.) != '']">
    <xsl:variable name="subref">
      <xsl:copy-of select="."/>
    </xsl:variable>
    <xsl:variable name="no-label"><xsl:if test="position() &gt; 1">1</xsl:if></xsl:variable>
    <xsl:apply-templates select="$field/*" mode="dataset-editing">
      <xsl:with-param name="e" select="concat($e, '[', position() -1, ']')"/>
      <xsl:with-param name="pos" select="position()"/>
      <xsl:with-param name="ref" select="$subref"/>
      <xsl:with-param name="no-label" select="$no-label"/>
    </xsl:apply-templates>
  </xsl:for-each>
  <xsl:variable name="no-label2"><xsl:if test="count($ref/*[name() = current()/name][normalize-space(.) != '']) &gt;= 1">1</xsl:if></xsl:variable>
  <xsl:apply-templates select="$field/*" mode="dataset-editing">
    <xsl:with-param name="e" select="concat($e, '[', count($ref/*[name() = current()/name][normalize-space(.) != '']), ']')"/>
    <xsl:with-param name="pos" select="count($ref/*[name() = current()/name][normalize-space(.) != ''])+1"/>
    <xsl:with-param name="no-label" select="$no-label2"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="field[type='boolean']|field[type='bool']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <label for="no"><input required="{@required}" title="{description}" label="{label}" type="radio" name="{$name}" id="no" value="0" onchange="pin_check('{type}', this)"><xsl:if test="not($value = 1)"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if></input> <xsl:value-of select="$labels/buttons/no"/></label>
    <label for="yes"><input required="{@required}" title="{description}" label="{label}" type="radio" name="{$name}" id="yes" value="1" onchange="pin_check('{type}', this)"><xsl:if test="$value = 1"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if></input> <xsl:value-of select="$labels/buttons/yes"/></label>
  </p>
</xsl:template>

<xsl:template match="field[type='tinytext']|field[type='smalltext']|field[contains(type, 'int')]" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <input required="{@required}" title="{description}" label="{label}" type="text" name="{$name}" id="{$name}" value="{$value}" class="textinput" onchange="pin_check('{type}', this)" />
  </p>
</xsl:template>

<xsl:template match="field[type='text']|field[type='mediumtext']|field[type='longtext']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="pos" select="1"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="rows"><xsl:choose><xsl:when test="type='text'">3</xsl:when><xsl:when test="type='mediumtext'">8</xsl:when><xsl:otherwise>16</xsl:otherwise></xsl:choose></xsl:variable>
  <!--<xsl:if test="not($no-label=1) and not(type='text')">-->
  <xsl:if test="not($no-label=1)">
    <p>
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="not($users/user[@id = $user]/wysiwyg-editor)">&#160;<a href="#" id="teditor{$pos}" name="teditor{$pos}" onclick="initEditor('{$name}');"><img src="{$base}/dav/images/wysiwyg.gif" width="15" height="18" alt="{$labels/content/activate_wysiwyg}" border="0" style="vertical-align: middle;" /></a></xsl:if>
    </p>
  </xsl:if>
  <p class="w100">
  <textarea required="{@required}" rows="{$rows}" description="{label}" name="{$name}" id="{$name}" class="textinput" onchange="pin_check('{type}', this)">
    <xsl:value-of select="$value"/>
  </textarea>
  </p>
</xsl:template>

<xsl:template match="field[type='date']|field[type='date-time']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="date-comp"><xsl:if test="type='date-time'">T<xsl:value-of select="substring-after($date, 'T')"/></xsl:if></xsl:variable>
  <p class="nobreak">
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <input required="{@required}" description="{label}" type="text" name="{$name}" id="{$name}" value="{$value}" class="textinput" style="width: 75%;" onchange="pin_check('{type}', this)" />
    <input type="button" value="..." class="submitinput" onclick="return showCalendar(this.previousSibling, 'y-mm-dd{$date-comp}');" style="width: 22%;" />
  </p>
</xsl:template>

<xsl:template match="field[(type='ref' or type='ref-value' or type='ref-copy') and @ref != '']" mode="dataset-editing">
  <xsl:param name="ref"><empty/></xsl:param>
  <xsl:param name="e" select="'dataset[ref]'"/>
  <xsl:param name="no-label"/>
  <xsl:variable name="index" select="@ref"/>
  <xsl:variable name="value">
    <xsl:choose>
      <xsl:when test="string($ref/*[name() = current()/name]/@ref) != ''"><xsl:value-of select="$ref/*[name() = current()/name]/@ref"/></xsl:when>
      <xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="subel" select="element" />
  
  <xsl:variable name="required" select="@required"/>
  <xsl:variable name="label" select="label"/>
  <xsl:variable name="type" select="type"/>
  <xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/><xsl:if test="type='ref'">[@xpml-id]</xsl:if><xsl:if test="type='ref-value'">[@xpml-value]</xsl:if><xsl:if test="type='ref-copy'">[@xpml-copy]</xsl:if></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <xsl:for-each select="document(@ref)/xpml">
      <xsl:choose>
        <xsl:when test="count(resource/*[@id != '']) &gt; 30">
          <xsl:variable name="output-value"><xsl:choose><xsl:when test="$subel != '' and contains($value, ':') and contains($value, '#')"><xsl:value-of select="document($value)"/></xsl:when><xsl:when test="$subel != '' and $value != '' and document(@ref)//*[name()=$subel]=$value"><xsl:value-of select="$value"/></xsl:when><xsl:when test="$value != ''"><xsl:value-of select="resource/*[@id = substring-after($value, '#')]/text()|resource/*[@id = substring-after($value, '#')]/*[1]/text()"/></xsl:when></xsl:choose></xsl:variable>
          <input required="{$required}" description="{$label}" type="hidden" name="{$name}" id="{$name}" value="{$value}" />
          <input name="tmp{$name}" id="tmp{$name}" value="{$output-value}" class="textinput" style="width: 75%;" onchange="pin_check('{type}', this)" />
          <input type="button" value="..." class="submitinput" onclick="pin_todo.action = 'pin_update_list(\'{$name}\', \'{$subel}\');';pin_list_index(this, '{$index}', '#{$output-value}')" style="width: 21%;" />
        </xsl:when>
        <xsl:otherwise>
          <select required="{$required}" description="{$label}" name="{$name}" id="{$name}" class="textinput" onchange="pin_check('{$type}', this)">
            <option value="">&#151;</option>
            <xsl:for-each select="resource/*[@id != '']">
              <xsl:sort />
              <xsl:choose>
                <xsl:when test="$subel != ''">
                  <option value="{$index}#{@id}.{$subel}"><xsl:if test="concat($index, '#', @id, '.', $subel) = $value or concat($index, '#', @id) = $value or (*[name() = $subel] = $value)"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if><xsl:value-of select="*[normalize-space(.) != ''][1]"/><xsl:if test="not(*[normalize-space(.) != ''][1])"><xsl:value-of select="."/></xsl:if></option>
                </xsl:when>
                <xsl:otherwise>
                  <option value="{$index}#{@id}"><xsl:if test="concat($index, '#', @id) = $value"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if><xsl:value-of select="*[normalize-space(.) != ''][1]"/><xsl:if test="not(*[normalize-space(.) != ''][1])"><xsl:value-of select="."/></xsl:if></option>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:for-each>
          </select>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </p>
</xsl:template>

<xsl:template match="field[type='multiple-ref' and @ref != '']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="index" select="@ref"/>
<xsl:variable name="value">
  <xsl:choose>
    <xsl:when test="value/@ref"><xsl:for-each select="value/@ref"><ref><xsl:value-of select="."/></ref></xsl:for-each></xsl:when>
    <xsl:when test="type='multiple-ref'"><xsl:copy-of select="$ref/*[name() = current()/name]"/></xsl:when>
    <xsl:when test="$ref/*[name() = current()/name]/@ref"><xsl:for-each select="$ref/*[name() = current()/name]/@ref"><ref><xsl:value-of select="."/></ref></xsl:for-each></xsl:when>
    <xsl:otherwise><xsl:for-each select="value"><ref><xsl:value-of select="."/></ref></xsl:for-each></xsl:otherwise>
  </xsl:choose>
</xsl:variable>
  <xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[][', name, ']')"/><xsl:if test="type='ref'">[@xpml-id]</xsl:if><xsl:if test="type='ref-value'">[@xpml-value]</xsl:if><xsl:if test="type='ref-copy'">[@xpml-copy]</xsl:if></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <select required="{@required}" size="3" description="{label}" multiple="multiple" name="{$name}" id="{$name}" class="textinput" onchange="pin_check('{type}', this)">
      <xsl:for-each select="document(@ref)/xpml/resource/*[@id != '']">
        <option value="{$index}#{@id}"><xsl:if test="concat($index, '#', @id) = $value/*"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if><xsl:value-of select="*[normalize-space(.) != ''][1]"/><xsl:if test="not(*[normalize-space(.) != ''][1])"><xsl:value-of select="."/></xsl:if></option>
      </xsl:for-each>
    </select>
    <xsl:if test="type='multiple-ref'"><input type="hidden" name="{$name}" id="{$name}" value="" /></xsl:if>
  </p>
</xsl:template>

<xsl:template match="field[type='set']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <select required="{@required}" description="{label}" type="text" name="{$name}" id="{$name}" class="textinput" onchange="pin_check('{type}', this)">
      <option value="">&#151;</option>
      <xsl:for-each select="select/ref">
        <xsl:choose>
          <xsl:when test="@id != ''">
            <option value="{@id}"><xsl:if test="@id = $value"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if><xsl:value-of select="."/></option>
          </xsl:when>
          <xsl:otherwise>
            <option value="{.}"><xsl:if test=". = $value"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if><xsl:value-of select="."/></option>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
    </select>
  </p>
</xsl:template>

<xsl:template match="field[type='binfile']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="pos" select="1"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
    <xsl:variable name="preview-url" select="concat($base, '/preview.dav?src=', $ref/*[name() = current()/name]/@ref-src)"/>
    <p><xsl:value-of select="label"/></p>
    <input type="hidden" name="{$name}[@xpml-file]" value="{$ref/*[name() = current()/name]/@ref-src}"/>
    <input type="hidden" name="{$name}[]" value="0"/>
    <div id="tmp{$pos}">
      <xsl:attribute name="style"><xsl:if test="$ref/*[name() = current()/name]/@ref-src">display:none;</xsl:if>width:49%</xsl:attribute>
      <input type="hidden" name="MAX_FILE_SIZE" value="10000000"/>
      <input type="hidden" name="{$name}[@xpml-import-upload-file]" value="resource-{$pos}"/>
      <input class="textinput" type="file" name="resource-{$pos}" />
    </div>
    <xsl:if test="$ref/*[name() = current()/name]/@ref-src">
    <div style="width:50%">
    <table cellpadding="0" cellspacing="0" border="0">
      <tr>
        <td style="padding: 1px 5px 0 5px; background: #eeeeee; color: #666666; border: 1px solid #666666" class="first" width="70%">
            <strong><a href="{$preview-url}&amp;name={$ref/*[name() = current()/name]/name}" target="_files"><xsl:value-of select="$ref/*[name() = current()/name]/name"/></a></strong>
            <br /><strong><xsl:value-of select="$labels/meta/format"/></strong><xsl:text>&#160;</xsl:text><xsl:value-of select="$ref/*[name() = current()/name]/format"/>
            <br /><strong><xsl:value-of select="$labels/meta/size"/></strong><xsl:text>&#160;</xsl:text><xsl:apply-templates mode="filesize" select="$ref/*[name() = current()/name]/size"/>
            <xsl:if test="substring-before($ref/*[name() = current()/name]/date, 'T') != ''">
              <br /><strong><xsl:value-of select="$labels/meta/issued"/></strong><xsl:text>&#160;</xsl:text><xsl:value-of select="substring-before($ref/*[name() = current()/name]/date, 'T')"/>
            </xsl:if>
        </td>
        <td width="30%">
          <input type="button" class="submitinput" onclick="pin_change_visibility('tmp{$pos}')" value=" ... " style="width:100%"/>
        </td>
      </tr>
    </table>
    </div>
    </xsl:if>
    <br />
</xsl:template>

<xsl:template match="field[@visibility='hidden']" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:variable name="value"><xsl:choose><xsl:when test="$ref/*[name() = current()/name] != ''"><xsl:value-of select="$ref/*[name() = current()/name]"/></xsl:when><xsl:otherwise><xsl:value-of select="value"/></xsl:otherwise></xsl:choose></xsl:variable>
<input type="hidden" name="{$name}" id="{$name}" value="{$value}" onchange="pin_check('{type}', this)" />
</xsl:template>

<xsl:template match="field[form]" mode="dataset-editing">
<xsl:param name="ref"><empty/></xsl:param>
<xsl:param name="e" select="'dataset[ref]'"/>
<xsl:param name="no-label"/>
<xsl:variable name="name"><xsl:choose><xsl:when test="@use-name!=''"><xsl:value-of select="@use-name"/></xsl:when><xsl:otherwise><xsl:value-of select="concat($e, '[', name, ']')"/></xsl:otherwise></xsl:choose></xsl:variable>
  <p>
    <xsl:if test="not($no-label=1)">
      <label for="{$name}"><xsl:value-of select="label"/></label>
      <xsl:if test="@required = 'yes'">*</xsl:if>
      <br />
    </xsl:if>
    <xsl:copy-of select="form/*"/>
  </p>
</xsl:template>

</xsl:stylesheet>