<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml"/>

<xsl:variable name="sitemap-position">
  <xsl:for-each select="$sitemap//page[@ref = $xpml/meta/identifier[@type='id']][1]">
    <ancestor><xsl:value-of select="../@ref"/><xsl:if test="../../root">root</xsl:if></ancestor>
    <position><xsl:value-of select="count(preceding-sibling::page) +1"/></position>
  </xsl:for-each>
</xsl:variable>
<xsl:variable name="sitemap-relations">
  <xsl:for-each select="$sitemap//page[@ref = $xpml/meta/identifier[@type='id']][1]/ancestor-or-self::page">
    <xsl:if test="position() = 1">
    <page>(home)</page>
    </xsl:if>
    <xsl:if test="position() != last()">
    <page position="{count(preceding-sibling::page) +1}" ref="{@ref}"><xsl:value-of select="document(@ref)/xpml/meta/title"/></page>
    </xsl:if>
  </xsl:for-each>
</xsl:variable>

<xsl:template match="meta" mode="dataset">
  <resource name="meta">
    <ref>
      <field required="no" use-name="meta[0][title]"><name>meta-title</name><label><xsl:value-of select="$labels/meta/title"/></label><type>tinytext</type><value><xsl:value-of select="title[not(@type='alternative')]"/></value></field>
      <field required="no" use-name="meta[1][title][@type]" visibility="hidden"><name>meta-title-alternative</name><type>tinytext</type><value>alternative</value></field>
      <field required="no" use-name="meta[1][title][]"><name>meta-title-alternative</name><label><xsl:value-of select="$labels/meta/alternative"/></label><type>tinytext</type><value><xsl:value-of select="title[@type='alternative']"/></value></field>
      <field required="no" use-name="meta[description]"><name>meta-description</name><label><xsl:value-of select="$labels/meta/description"/></label><type>text</type><value><xsl:value-of select="description"/></value></field>
      <field required="no" use-name="meta[][subject][@ref]" ref="index:subject"><name>meta-subject</name><label><xsl:value-of select="$labels/meta/subject"/></label><type>multiple-ref</type><xsl:for-each select="subject"><value ref="{@ref}"><xsl:copy-of select="key"/></value></xsl:for-each></field>
      <field required="no" use-name="meta[language]"><name>meta-language</name><label><xsl:value-of select="$labels/meta/language"/></label><type>set</type><value><xsl:value-of select="language"/></value><select><xsl:for-each select="$lang/*"><ref id="{name()}"><xsl:value-of select="."/></ref></xsl:for-each></select></field>
      <field required="no" use-name="meta[source]"><name>meta-source</name><label><xsl:value-of select="$labels/meta/source"/></label><type>tinytext</type><value><xsl:value-of select="source"/></value></field>
      <field required="no" use-name="meta[date][@type]" visibility="hidden"><name>meta-date</name><type>tinytext</type><value>issued</value></field>
      <field required="no" use-name="meta[date][]"><name>meta-date</name><label><xsl:value-of select="$labels/meta/date"/></label><type>date</type><value><xsl:value-of select="date[@type='alternative']"/></value></field>
      <field required="no" use-name="meta[][creator][@ref]" ref="index:authors"><name>meta-creator</name><label><xsl:value-of select="$labels/meta/creator"/></label><type>multiple-ref</type><xsl:for-each select="creator"><value ref="{@ref}"><xsl:copy-of select="name"/></value></xsl:for-each></field>
      <field required="no" use-name="meta[][publisher][@ref]" ref="index:publishers"><name>meta-publisher</name><label><xsl:value-of select="$labels/meta/publisher"/></label><type>multiple-ref</type><xsl:for-each select="publisher"><value ref="{@ref}"><xsl:copy-of select="name"/></value></xsl:for-each></field>
      <field required="no" use-name="meta[][contributor][@ref]" ref="index:authors"><name>meta-contributor</name><label><xsl:value-of select="$labels/meta/contributor"/></label><type>multiple-ref</type><xsl:for-each select="contributor"><value ref="{@ref}"><xsl:copy-of select="name"/></value></xsl:for-each></field>
      <field required="no" use-name="meta[0][rights][@ref]"><name>meta-rights</name><label><xsl:value-of select="$labels/meta/rights"/></label><type>tinytext</type><form><xsl:apply-templates select="rights" mode="meta"/><xsl:if test="not(rights)"><xsl:variable name="tmprights"><rights/></xsl:variable><xsl:apply-templates select="$tmprights/*" mode="meta"/></xsl:if></form></field>
      <field required="no" use-name="meta[type]"><name>meta-type</name><label><xsl:value-of select="$labels/meta/type"/></label><type>set</type><value><xsl:value-of select="type"/></value><select><xsl:for-each select="$types/*"><ref id="{name()}"><xsl:value-of select="."/></ref></xsl:for-each></select></field>
      <field required="no" use-name="meta[format]"><name>meta-format</name><label><xsl:value-of select="$labels/meta/format"/></label><type>set</type><value><xsl:value-of select="format"/></value><select><xsl:for-each select="document('arg:mime_types')/mime_types/*[name() = current()/type]/*"><ref id="{.}"><xsl:value-of select="."/></ref></xsl:for-each></select></field>
      <!--
      <field required="no" use-name="meta[identifier]"><name>meta-identifier</name><label><xsl:value-of select="$labels/meta/url"/></label><type>tinytext</type><form><xsl:apply-templates select="identifier[@type='url']" mode="meta"/><xsl:if test="not(identifier[@type='url'] != '')"><xsl:variable name="tmpidentifier"><identifier type="url"/></xsl:variable><xsl:apply-templates select="$tmpidentifier/*" mode="meta"/></xsl:if></form></field>
      <field required="no" use-name="meta[identifier]" ref="index:uris"><name>meta-identifier</name><label><xsl:value-of select="$labels/meta/url"/></label><type>ref-value</type><form><xsl:apply-templates select="identifier[@type='url']" mode="meta"/><xsl:if test="not(identifier[@type='url'] != '')"><xsl:variable name="tmpidentifier"><identifier type="url"/></xsl:variable><xsl:apply-templates select="$tmpidentifier/*" mode="meta"/></xsl:if></form></field>
      -->
    </ref>
  </resource>
</xsl:template>

<xsl:template match="meta">
  <xsl:variable name="meta_dataset">
    <xsl:apply-templates select="." mode="dataset"/>
  </xsl:variable>
  <xsl:variable name="read-only">
    <xsl:choose>
      <xsl:when test="normalize-space($read-only) = 'all'">all</xsl:when>
      <xsl:otherwise><xsl:value-of select="$read-only"/><xsl:if test="contains($request/get/id, '.')"> meta-identifier meta-relation-sitemap meta-type meta-format </xsl:if></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="icon"><img src="{$base}/dav/images/seta.gif" width="9" height="9" border="0" alt="{$labels/buttons/edit}" style="vertical-align: middle; text-align: right; margin-right: 5px;" /></xsl:variable>
  <xsl:variable name="icon-off"><img src="{$base}/dav/images/seta_off.gif" width="9" height="9" border="0" alt="-&lt;" style="vertical-align: middle; text-align: right; margin-right: 5px;" /></xsl:variable>
  <div class="meta">
    <table cellpadding="0" cellspacing="0" border="0" width="100%">
      <xsl:for-each select="$meta_dataset/resource/ref/field">
      <xsl:choose>
        <xsl:when test="@visibility ='hidden' and contains($read-only, concat(name,' ')) or normalize-space($read-only) = 'all'">
          <tr>
            <td class="labels">
              <p><label for="{@use-name}"><xsl:value-of select="label"/></label></p>
            </td>
            <td><p><xsl:copy-of select="$icon-off/*"/></p></td>
            <td>
              <div class="visible">
              <xsl:choose>
                <xsl:when test="not(value != '')"><span class="undef"><xsl:value-of select="$labels/meta/undef"/></span></xsl:when>
                <xsl:when test="type='set'"><xsl:value-of select="select/*[name() = current()/value]"/></xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="value" mode="list" />
                  <!--<xsl:apply-templates select="." mode="dataset-editing">
                    <xsl:with-param name="no-label" select="1"/>
                  </xsl:apply-templates>-->
                </xsl:otherwise>
              </xsl:choose>
              </div>
            </td>
          </tr>
        </xsl:when>
        <xsl:when test="not(@visibility ='hidden')">
          <tr>
            <td class="labels">
              <p><label for="{@use-name}"><xsl:value-of select="label"/></label></p>
            </td>
            <td>
              <xsl:choose>
                <xsl:when test="contains($read-only, concat(name,' ')) or normalize-space($read-only) = 'all'"><p><xsl:copy-of select="$icon-off/*"/></p></xsl:when>
                <xsl:otherwise><p><a href="#" onclick="pin_replace('{name}', '{substring-after(name, 'meta-')}')"><xsl:copy-of select="$icon/*"/></a></p></xsl:otherwise>
              </xsl:choose>
            </td>
            <td>
              <div name="{name}" id="{name}" class="visible">
              <xsl:choose>
                <xsl:when test="not(value != '')"><span class="undef"><xsl:value-of select="$labels/meta/undef"/></span></xsl:when>
                <xsl:when test="type='set'"><xsl:apply-templates mode="list" select="select/ref[@id = current()/value]"/></xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="value" mode="list" />
                  <!--<xsl:apply-templates select="." mode="dataset-editing">
                    <xsl:with-param name="no-label" select="1"/>
                  </xsl:apply-templates>-->
                </xsl:otherwise>
              </xsl:choose>
              </div>
            </td>
          </tr>
        </xsl:when>
      </xsl:choose>
      </xsl:for-each>
      <tr>
        <td class="labels">
          <p><xsl:value-of select="$labels/meta/url"/></p>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="contains($read-only, 'meta-identifier ') or normalize-space($read-only) = 'all'"><p><xsl:copy-of select="$icon-off/*"/></p></xsl:when>
            <xsl:otherwise><xsl:variable name="dir"><xsl:call-template name="dirname"><xsl:with-param name="dir" select="identifier[@type='url']"/></xsl:call-template></xsl:variable><p><a href="#" onclick="pin_todo.action = 'pin_update_uri';pin_choose_index('?dir={$dir}', 'uris-insert')"><xsl:copy-of select="$icon/*"/></a></p></xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <div name="meta-identifier" id="meta-identifier" class="visible" title="{identifier[@type='url']}">
            <xsl:value-of select="substring(identifier[@type='url'], 1, 20)"/>
            <xsl:if test="string-length(identifier[@type='url']) &gt; 20">&#133;</xsl:if>
            <xsl:if test="not(identifier[@type='url'])"><span class="undef"><xsl:value-of select="$labels/meta/undef"/></span></xsl:if>
          </div>
        </td>
      </tr>
      <tr>
        <td class="labels"><p><label for="meta[relation][ancestor]"><xsl:value-of select="$labels/meta/sitemap"/></label></p></td>
        <td>
          <xsl:choose>
            <xsl:when test="contains($read-only, 'meta-relation-sitemap ') or normalize-space($read-only) = 'all'"><p><xsl:copy-of select="$icon-off/*"/></p></xsl:when>
            <xsl:otherwise><p><a href="#" onclick="pin_todo.action = 'pin_update_sitemap';pin_choose_index('?id={identifier[@type='id']}', 'sitemap-select')"><xsl:copy-of select="$icon/*"/></a></p></xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <div name="meta-relation-sitemap" id="meta-relation-sitemap" class="visible">
            <xsl:for-each select="$sitemap-relations/page">
              <xsl:value-of select="."/><xsl:text>  </xsl:text>
            </xsl:for-each>
            <xsl:if test="not($sitemap-relations/page)"><span class="undef"><xsl:value-of select="$labels/meta/undef"/></span></xsl:if>
          </div>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>


<xsl:template match="*" mode="meta">
</xsl:template>

<xsl:template match="relation" mode="meta">
  <div id="relation" name="relation">
    <input type="text" name="meta[][relation][@ref]" value="." class="textinput" readonly="readonly" />
  </div>
</xsl:template>

<xsl:template match="relation[@type='sitemap']" mode="meta">
  <div id="relation-sitemap" name="relation-sitemap">
    <input type="hidden" name="meta-relation[@type]" value="sitemap" />
    <select name="meta-relation[ref-type]" id="meta-relation[ref-type]" class="textinput" style="width: 70px;">
      <option value="ancestor"><xsl:value-of select="$labels/meta/relations_child"/></option>
      <option value="preceding-sibling"><xsl:value-of select="$labels/meta/relations_after"/></option>
      <option value="following-sibling"><xsl:value-of select="$labels/meta/relations_before"/></option>
    </select>
    <input type="hidden" name="meta-relation[ref]" value="{$sitemap-position/ancestor}" />
    <xsl:variable name="value">
      <xsl:choose>
        <xsl:when test="$sitemap-position/ancestor != 'root'"><xsl:value-of select="document($sitemap-position/ancestor)/xpml/meta/title"/></xsl:when>
        <xsl:otherwise>home</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <input type="text" name="tmp-meta-relation[ref]" value="{$value}" class="textinput" readonly="readonly" style="width: 90px;" />
  </div>
</xsl:template>

<xsl:template mode="meta" match="identifier[@type='url']">
  <div name="{name()}" id="{name()}">
    <input type="text" class="textinput" readonly="readonly" name="meta[identifier]" value="{.}" onchange="pin_check('identifier', this)" />
  </div>
</xsl:template>

<xsl:template match="rights" mode="meta">
  <xsl:if test="count(preceding-sibling::rights) = 0">
  <xsl:variable name="groups" select="document('arg:groups')/groups"/>
  <div id="rights" name="rights">
    <xsl:for-each select="$xpml/meta/rights[normalize-space(.) != '' and @ref != '']">
      <xsl:variable name="curr" select="."></xsl:variable>
      <label for="meta[{position()-1}][rights][@ref]"><xsl:value-of select="$labels/meta/group"/></label><br />
      <input type="hidden" name="meta[{position()-1}][rights][@type]" value="access-rights"/>
      <select name="meta[{position()-1}][rights][@ref]" id="meta[{position()-1}][rights][@ref]" class="textinput">
        <option value="">&#151;</option>
        <xsl:for-each select="$groups/*[name()= $curr/@ref]">
          <option value="{name()}">
            <xsl:if test="$curr/@ref = name()"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if>
            <xsl:value-of select="name()"/>
          </option>
        </xsl:for-each>
      </select>
      <br />
      <label for="meta[{position()-1}][rights][][action]"><xsl:value-of select="$labels/meta/actions"/></label><br />
      <select size="3" multiple="multiple" name="meta[{position()-1}][rights][][action]" id="meta[{position()-1}][rights][][action]" class="textinput">
        <xsl:for-each select="$rights/*">
          <option value="{name()}">
            <xsl:if test="$curr/action = name()"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if>
            <xsl:value-of select="."/>
          </option>
        </xsl:for-each>
      </select>
      <br /><br />
    </xsl:for-each>
    <xsl:if test="count($xpml/meta/rights[normalize-space(.) != '' and @ref != '']) &lt; count($groups/*)">
    <xsl:variable name="count" select="count($xpml/meta/rights[normalize-space(.) != '' and @ref != ''])"/>
    <label for="meta[{$count}][rights][@ref]"><xsl:value-of select="$labels/meta/group"/></label><br />
    <input type="hidden" name="meta[{$count}][rights][@type]" value="access-rights"/>
    <select name="meta[{$count}][rights][@ref]" id="meta[{$count}][rights][@ref]" class="textinput">
      <option value="">&#151;</option>
      <xsl:for-each select="$groups/*[not(name()= $xpml/meta/rights/@ref)]">
        <option value="{name()}"><xsl:value-of select="name()"/></option>
      </xsl:for-each>
    </select>
    <br />
    <label for="meta[{$count}][rights][][action]"><xsl:value-of select="$labels/meta/actions"/></label><br />
    <select multiple="multiple" size="3" name="meta[{$count}][rights][][action]" id="meta[{$count}][rights][][action]" class="textinput">
      <xsl:for-each select="$rights/*">
        <option value="{name()}"><xsl:value-of select="."/></option>
      </xsl:for-each>
    </select>
    </xsl:if>
  </div>
  </xsl:if>
</xsl:template>

<xsl:template match="meta" mode="meta-hidden">
  <xsl:variable name="xpml"><xsl:copy-of select="."/></xsl:variable>
  <xsl:variable name="meta">
    <meta>
    <xsl:for-each select="$defaults/meta/*">
      <xsl:variable name="name" select="name()"/>
      <xsl:variable name="type" select="@type"/>
      <xsl:choose>
        <xsl:when test="$xpml/meta/*[concat(name(), '-', @type) = concat($name, '-', $type)]">
          <xsl:copy-of select="$xpml/meta/*[concat(name(), '-', @type) = concat($name, '-', $type)]"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
    </meta>
  </xsl:variable>

  <xsl:variable name="meta_dataset">
    <xsl:apply-templates select="$meta/meta" mode="dataset"/>
  </xsl:variable>

  <xsl:variable name="read-only">
    <xsl:choose>
      <xsl:when test="normalize-space($read-only) = 'all'">all</xsl:when>
      <xsl:otherwise><xsl:value-of select="$read-only"/><xsl:if test="contains($request/get/id, '.')"> meta-identifier meta-relation-sitemap meta-type meta-format </xsl:if></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="$meta_dataset/resource/ref/field">
    <xsl:if test="not(preceding-sibling::field[name = current()/name])">
      <div id="{substring-after(name, 'meta-')}" name="{substring-after(name, 'meta-')}">
        <xsl:apply-templates select=".|following-sibling::field[name = current()/name]" mode="dataset-editing">
          <xsl:with-param name="no-label" select="1"/>
        </xsl:apply-templates>
      </div>
    </xsl:if>
  </xsl:for-each>
  <div id="identifier" name="identifier">
    <xsl:apply-templates select="$meta/meta/identifier[@type='url']" mode="meta"/>
  </div>
  <div id="relation-sitemap" name="relation-sitemap">
    <xsl:apply-templates select="$meta/meta/relation[@type='sitemap']" mode="meta"/>
  </div>

</xsl:template>

<xsl:template mode="javascript" match="*">
  <xsl:variable name="tmp">
    <xsl:text>meta-</xsl:text>
    <xsl:value-of select="name()"/>
    <xsl:if test="@type">-<xsl:value-of select="@type"/></xsl:if>
  </xsl:variable>
  <xsl:if test="not(normalize-space($read-only) = 'all') and not(contains($read-only, $tmp))">
  <script><noscript><xsl:apply-templates mode="meta" select="."/></noscript></script>
  </xsl:if>
</xsl:template>


<xsl:template match="*" mode="list">
<xsl:if test="position() != 1">, </xsl:if>
<xsl:choose>
  <xsl:when test="string-length(.) > 30"><xsl:value-of select="concat(substring(., 1, 30), substring-before(substring(., 31), ' '), '...')"/></xsl:when>
  <xsl:otherwise><xsl:value-of select="."/></xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="*" mode="list-keys">
<xsl:if test="position() != 1">, </xsl:if>
<xsl:value-of select="@ref"/><xsl:text> (</xsl:text><xsl:apply-templates select="$rights/*[name() = current()/action/text()]" mode="list"/><xsl:text>)</xsl:text>
</xsl:template>

<xsl:template name="dirname">
<xsl:param name="dir"/>
  <xsl:if test="contains($dir, '/')">
  <xsl:value-of select="substring-before($dir, '/')"/>
  <xsl:text>/</xsl:text>
  <xsl:call-template name="dirname"><xsl:with-param name="dir" select="substring-after($dir, '/')"/></xsl:call-template>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>