<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="no" method="xml" omit-xml-declaration="no"/>


<xsl:template match="meta" priority="1">
  <meta>
    <xsl:apply-templates select="@*[name() = 'name' or starts-with(name(), 'xpml')]"/>

    <!-- title -->
    <title>
      <xsl:choose>
        <xsl:when test="$post/meta/title[not(@type='alternative')] != ''"><xsl:value-of select="$post/meta/title[not(@type='alternative')]"/></xsl:when>
        <xsl:when test="title[not(@type='alternative')] != ''"><xsl:value-of select="title[not(@type='alternative')]"/></xsl:when>
        <xsl:otherwise><xsl:value-of select="$defaults/title[not(@type='alternative')]"/></xsl:otherwise>
      </xsl:choose>
    </title>
    <xsl:choose>
      <xsl:when test="$post/meta/title[@type='alternative']">
        <xsl:apply-templates select="$post/meta/title[@type='alternative']" mode="copy"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="title[@type='alternative']"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- creator -->
    <xsl:choose>
      <xsl:when test="$post/meta/creator">
        <xsl:for-each select="$post/meta/creator[@ref != '']">
          <creator ref="{@ref}">
            <xsl:choose>
              <xsl:when test="contains(@ref, '#')">
                <xsl:apply-templates select="document(substring-before(@ref, '#'))/xpml/resource/ref[@id = substring-after(current()/@ref, '#')]" mode="pre-copy"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="document(@ref)/*">
                  <xsl:copy-of select="*|text()"/>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </creator>
        </xsl:for-each>
        <xsl:for-each select="$post/meta/creator[. != '' and not(@ref != '')]">
          <creator>
            <xsl:copy-of select="./*|text()"/>
          </creator>
        </xsl:for-each>
      </xsl:when>
      <xsl:when test="normalize-space(creator) != '' or normalize-space(creator/@ref) != ''">
        <xsl:copy-of select="creator"/>
      </xsl:when>
    </xsl:choose>

    <!-- subject -->
    <xsl:choose>
      <xsl:when test="$post/meta/subject">a
        <xsl:for-each select="$post/meta/subject[@ref != '']">
          <subject ref="{@ref}">
            <xsl:choose>
              <xsl:when test="contains(@ref, '#')">
                <xsl:apply-templates select="document(substring-before(@ref, '#'))/xpml/resource/ref[@id = substring-after(current()/@ref, '#')]" mode="pre-copy"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="document(@ref)/*">
                  <xsl:copy-of select="*|text()"/>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </subject>
        </xsl:for-each>
        <xsl:for-each select="$post/meta/subject[. != '' and not(@ref != '')]">
          <subject>
            <xsl:copy-of select="./*|text()"/>
          </subject>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="subject"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- description -->
    <xsl:choose>
      <xsl:when test="$post/meta/description"><xsl:apply-templates select="$post/meta/description" mode="copy"/></xsl:when>
      <xsl:otherwise><xsl:copy-of select="description"/></xsl:otherwise>
    </xsl:choose>

    <!-- publisher -->
    <xsl:choose>
      <xsl:when test="$post/meta/publisher">
        <xsl:for-each select="$post/meta/publisher[@ref != '']">
          <publisher ref="{@ref}">
            <xsl:choose>
              <xsl:when test="contains(@ref, '#')">
                <xsl:apply-templates select="document(substring-before(@ref, '#'))/xpml/resource/ref[@id = substring-after(current()/@ref, '#')]" mode="pre-copy"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="document(@ref)/*">
                  <xsl:copy-of select="*|text()"/>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </publisher>
        </xsl:for-each>
        <xsl:for-each select="$post/meta/publisher[. != '' and not(@ref != '')]">
          <publisher>
            <xsl:copy-of select="./*|text()"/>
          </publisher>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="publisher"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- contributor -->
    <xsl:choose>
      <xsl:when test="$post/meta/contributor">
        <xsl:for-each select="$post/meta/contributor[@ref != '']">
          <contributor ref="{@ref}">
            <xsl:choose>
              <xsl:when test="contains(@ref, '#')">
                <xsl:apply-templates select="document(substring-before(@ref, '#'))/xpml/resource/ref[@id = substring-after(current()/@ref, '#')]" mode="pre-copy"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="document(@ref)/*">
                  <xsl:copy-of select="*|text()"/>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </contributor>
        </xsl:for-each>
        <xsl:for-each select="$post/meta/contributor[. != '' and not(@ref != '')]">
          <contributor>
            <xsl:copy-of select="./*|text()"/>
          </contributor>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="contributor"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- date -->
    <xsl:choose>
      <xsl:when test="date[@type = 'created'] != ''"><xsl:copy-of select="date[@type = 'created']"/></xsl:when>
      <xsl:otherwise><date type="created"><xsl:value-of select="$date"/></date></xsl:otherwise>
    </xsl:choose>
    <date type="modified"><xsl:value-of select="$date"/></date>
    <xsl:choose>
      <xsl:when test="$post/meta/date[@type != 'created' and @type != 'modified']">
        <xsl:for-each select="$post/meta/date[@type != 'created' and @type != 'modified' and . != '']">
          <xsl:copy-of select="."/>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="date[@type != 'created' and @type != 'modified']"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- type -->
    <xsl:choose>
      <xsl:when test="contains($xpml-identifier, '.')">
        <xsl:copy-of select="document(substring-before($xpml-identifier, '.'))/xpml/meta/type"/>
      </xsl:when>
      <xsl:when test="$post/meta/type != ''">
        <type><xsl:value-of select="$post/meta/type"/></type>
      </xsl:when>
      <xsl:when test="type != ''">
        <xsl:copy-of select="type"/>
      </xsl:when>
      <xsl:otherwise>
        <type><xsl:value-of select="$defaults/format"/></type>
      </xsl:otherwise>
    </xsl:choose>

    <!-- format -->
    <xsl:choose>
      <xsl:when test="contains($xpml-identifier, '.')">
        <xsl:copy-of select="document(substring-before($xpml-identifier, '.'))/xpml/meta/format"/>
      </xsl:when>
      <xsl:when test="$post/meta/format != ''">
        <format><xsl:value-of select="$post/meta/format"/></format>
      </xsl:when>
      <xsl:when test="format != ''">
        <xsl:copy-of select="format"/>
      </xsl:when>
      <xsl:otherwise>
        <format><xsl:value-of select="$defaults/format"/></format>
      </xsl:otherwise>
    </xsl:choose>

    <!-- identifier -->
    <identifier type="id"><xsl:value-of select="$xpml-identifier"/></identifier>
    <xsl:choose>
      <xsl:when test="contains($xpml-identifier, '.')">
        <xsl:copy-of select="document(substring-before($xpml-identifier, '.'))/xpml/meta/identifier[@type='url']"/>
      </xsl:when>
      <xsl:when test="$post/meta/identifier">
        <xsl:for-each select="$post/meta/identifier[. != '']">
          <identifier type="url"><xsl:value-of select="."/></identifier>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="identifier[@type='url']"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- source -->
    <xsl:choose>
      <xsl:when test="normalize-space($post/meta/source) != ''">
        <source type="url"><xsl:value-of select="normalize-space($post/meta/source)"/></source>
      </xsl:when>
      <xsl:when test="normalize-space(source) != ''">
        <xsl:copy-of select="source"/>
      </xsl:when>
    </xsl:choose>

    <!-- language -->
    <xsl:choose>
      <xsl:when test="$post/meta/language != ''">
        <language><xsl:value-of select="$post/meta/language"/></language>
      </xsl:when>
      <xsl:when test="language != ''">
        <xsl:copy-of select="language"/>
      </xsl:when>
      <xsl:otherwise>
        <language><xsl:value-of select="$defaults/language"/></language>
      </xsl:otherwise>
    </xsl:choose>

    <!-- relation -->
    <xsl:choose>
      <xsl:when test="contains($xpml-identifier, '.')">
        <xsl:copy-of select="document(substring-before($xpml-identifier, '.'))/xpml/meta/relation[(. != '' or @ref != '') and @type != '']"/>
      </xsl:when>
      <xsl:when test="$post/meta/relation">
        <xsl:copy-of select="$post/meta/relation[(. != '' or @ref != '') and @type != '']"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="relation[(. != '' or @ref != '') and @type != '']"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- coverage -->
    <xsl:choose>
      <xsl:when test="$post/meta/coverage">
        <xsl:copy-of select="$post/meta/coverage[. != '' and @type != '']"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="coverage[. != '' and @type != '']"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- rights -->
    <xsl:choose>
      <xsl:when test="$update-rights != ''">
        <xsl:value-of select="$update-rights" disable-output-escaping="yes"/>
      </xsl:when>
      <xsl:when test="$post/meta/rights">
        <xsl:copy-of select="$post/meta/rights[. != '']"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="rights[. != '']"/>
      </xsl:otherwise>
    </xsl:choose>

  </meta>
</xsl:template>

</xsl:stylesheet>