<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="no" method="xml" omit-xml-declaration="no"/>

<xsl:param name="date"/>
<xsl:param name="update-rights"/>
<xsl:param name="xpml-identifier" select="/xpml/meta/identifier[@type='id']"/>
<xsl:variable name="request" select="document('arg:request')/request"/>
<xsl:variable name="post"><xsl:copy-of select="$request/post/*"/></xsl:variable>
<xsl:variable name="files"><xsl:copy-of select="$request/files/*"/></xsl:variable>
<xsl:variable name="defaults" select="document('arg:defaults')/defaults"/>
<xsl:variable name="xpml">
  <xsl:choose>
    <xsl:when test="$request/get/merge != '' and not(resource[@type='dataset'])">
      <xsl:variable name="o-meta"><xsl:copy-of select="/xpml/meta/identifier|/xpml/meta/format|/xpml/meta/relation|/xpml/meta/type"/></xsl:variable>
      <xsl:for-each select="document($request/get/merge)/xpml">
        <meta>
          <xsl:copy-of select="$o-meta/*"/>
          <xsl:copy-of select="meta/*[not(name()='identifier') and not(name()='format') and not(name()='relation') and not(name()='type')]"/>
        </meta>
        <xsl:copy-of select="*[not(name() = 'meta')]"/>
      </xsl:for-each>
    </xsl:when>
    <xsl:otherwise>
      <xsl:copy-of select="/xpml/*"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:include href="components_update.xsl"/>
<xsl:include href="dav_meta_update.xsl"/>

<xsl:template match="/">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="*[not(@xpml-import != '')]">
  <xsl:variable name="name" select="name()"/>
  <xsl:variable name="type" select="@type"/>
  <xsl:variable name="id" select="@id"/>
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="*[@xpml-import != '']">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="xpml" priority="1">
<xpml version="0.1">
  <xsl:apply-templates select="@*[name() != 'version']"/>
  <xsl:apply-templates select="$xpml/*[name() != 'resource']"/>
  <xsl:variable name="resources">
    <xsl:apply-templates select="$xpml/resource" mode="resource"/>
    <xsl:apply-templates select="$post/x/resource[not(@id = $xpml/resource/@id)]" mode="resource" />
  </xsl:variable>
  <xsl:for-each select="$resources/resource[count(*) &gt; 0 or normalize-space(.) != '']">
    <resource>
      <xsl:if test="not(@type = 'dataset')"><xsl:attribute name="id"><xsl:value-of select="concat($xpml-identifier, '#', count(preceding-sibling::resource) +1)"/></xsl:attribute></xsl:if>
      <xsl:apply-templates select="@*[name() != 'id']" mode="blind-copy"/>
      <xsl:apply-templates select="*" mode="blind-copy"/>
    </resource>
  </xsl:for-each>
</xpml>
</xsl:template>

<xsl:template match="resource" mode="resource">
  <xsl:choose>
    <xsl:when test="@xpml-import != ''">
      <xsl:apply-templates select="."/>
    </xsl:when>
    <xsl:when test="$post/x/resource/@id = current()/@id">
      <xsl:apply-templates select="$post/x/resource[@id = current()/@id]" />
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template mode="pre-copy" match="*">
  <xsl:apply-templates mode="copy"/>
</xsl:template>

<xsl:template mode="copy" match="*">
  <xsl:if test=". != '' or */@*[starts-with(name(), 'xpml')] != ''">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates mode="copy"/>
    </xsl:element>
  </xsl:if>
</xsl:template>

<xsl:template mode="copy" match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template mode="blind-copy" match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="blind-copy" match="*">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*" mode="blind-copy"/>
    <xsl:apply-templates mode="blind-copy"/>
  </xsl:element>
</xsl:template>
   
<xsl:template mode="blind-copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="@*" mode="blind-copy">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template match="*[normalize-space(.) = '' and not(starts-with(name(*/@*), 'xpml-')) and not(starts-with(name(@*), 'xpml-'))]" priority="1">
</xsl:template>

<xsl:template match="*[normalize-space(.) = '' and not(starts-with(name(*/@*[. != '']), 'xpml-')) and not(starts-with(name(@*[. != '']), 'xpml-'))]" priority="1">
</xsl:template>


</xsl:stylesheet>