<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xml"/>

<xsl:param name="versions"/>
<xsl:variable name="next-version"><xsl:call-template name="next-version"/></xsl:variable>

<xsl:template name="next-version">
  <xsl:param name="id" select="$xpml/meta/identifier[@type='id']"/>
  <xsl:param name="int" select="1"/>
  <xsl:choose>
    <xsl:when test="contains($versions, concat($id, '.', $int, '-', $user))">
      <xsl:call-template name="next-version">
        <xsl:with-param name="id" select="$id"/>
        <xsl:with-param name="int" select="$int +1"/>
      </xsl:call-template> 
    </xsl:when>
    <xsl:otherwise><xsl:value-of select="concat($int, '-', $user)"/></xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template mode="version-control" match="*">
<xsl:if test="$versions != '' or contains($xpml/meta/identifier[@type='id'], '.')">
  <div class="meta" style="background:none">
  <br />
  <h3><xsl:value-of select="$labels/versions/title"/></h3>
  <xsl:if test="contains($xpml/meta/identifier[@type='id'], '.')">
    <p><xsl:value-of select="$labels/versions/original"/></p>
    <table cellpadding="0" cellspacing="0" border="0" width="100%">
      <tbody>
        <tr>
          <th class="first"><xsl:value-of select="$labels/meta/title"/></th>
          <th><xsl:value-of select="$labels/meta/date_modified"/></th>
        </tr>
        <xsl:call-template name="version-details"><xsl:with-param name="o"><xsl:call-template name="last-version"/></xsl:with-param></xsl:call-template>
      </tbody>
    </table>
  </xsl:if>
  <xsl:if test="$versions != ''">
    <p><xsl:value-of select="$labels/versions/copies"/></p>
    <table cellpadding="0" cellspacing="0" border="0" width="100%">
      <tbody>
        <tr>
          <th class="first"><xsl:value-of select="$labels/meta/title"/></th>
          <th><xsl:value-of select="$labels/meta/date_modified"/></th>
        </tr>
        <xsl:call-template name="version-details"><xsl:with-param name="v" select="normalize-space($versions)"/></xsl:call-template>
      </tbody>
    </table>
  </xsl:if>
  </div>
</xsl:if>
</xsl:template>

<xsl:template name="version-details">
  <xsl:param name="v"/>
  <xsl:param name="o"/>
  <xsl:if test="$v != ''">
    <xsl:variable name="id"><xsl:value-of select="substring-before($v, ' ')"/><xsl:if test="substring-before($v, ' ') = ''"><xsl:value-of select="$v"/></xsl:if></xsl:variable>
    <tr onMouseOver="this.bgColor='#ccddcd';" onMouseOut="this.bgColor='#fafffe';" class="tablerow">
      <xsl:for-each select="document($id)/xpml/meta">
        <td class="first"><a href="{$script-name}?id={$id}"><xsl:value-of select="title"/></a></td>
        <td><a href="{$script-name}?id={$id}"><xsl:apply-templates select="date[@type='modified']" mode="diff-date"/></a></td>
      </xsl:for-each>
      <td style="vertical-align:middle"><a href="{$action}&amp;merge={$v}"><img src="{$base}/dav/images/dav_merge.gif" width="20px" height="11px" alt="{$labels/buttons/save_merge}" border="0" /></a></td>
    </tr>
    <xsl:call-template name="version-details"><xsl:with-param name="v" select="normalize-space(substring-after($v, $id))"/></xsl:call-template>
  </xsl:if>
  <xsl:if test="$o != ''">
    <tr onMouseOver="this.bgColor='#ccddcd';" onMouseOut="this.bgColor='#fafffe';" class="tablerow">
      <xsl:for-each select="document($o)/xpml/meta">
        <td class="first"><a href="{$script-name}?id={$o}"><xsl:value-of select="title"/></a></td>
        <td><a href="{$script-name}?id={$o}"><xsl:value-of select="date[@type='modified']"/></a></td>
      </xsl:for-each>
      <td style="vertical-align:middle"><a href="{$action}&amp;merge={$xpml/meta/identifier[@type='id']}"><img src="{$base}/dav/images/dav_merge.gif" width="20px" height="11px" alt="{$labels/buttons/save_merge}" border="0" /></a></td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="last-version">
<xsl:param name="id" select="$xpml/meta/identifier[@type='id']"/>
  <xsl:if test="substring-after($id, '.') != ''">
    <xsl:value-of select="substring-before($id, '.')"/>
    <xsl:if test="contains(substring-after($id, '.'), '.')">
      <xsl:text>.</xsl:text>
      <xsl:call-template name="last-version"><xsl:with-param name="id" select="substring-after($id, '.')"/></xsl:call-template>
    </xsl:if>
  </xsl:if>
</xsl:template>

<xsl:template match="*" mode="diff-date">
  <xsl:param name="date" select="$date"/>
<xsl:if test="substring(., 1, 10) != substring($date, 1, 10)"><xsl:value-of select="substring(., 1, 10)"/>&#160;</xsl:if>
<xsl:value-of select="substring(., 12, 5)"/>
</xsl:template>
</xsl:stylesheet>