<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml" omit-xml-declaration="yes"/>

<xsl:param name="auth-user"/>
<xsl:param name="title"/>

<xsl:include href="dav_header.xsl"/>
<xsl:include href="dav_meta.xsl"/>
<xsl:include href="dav_components.xsl"/>

<xsl:variable name="meta">
  <meta>
  <title><xsl:value-of select="$title"/></title>
  </meta>
</xsl:variable>
<xsl:variable name="datasets" select="document('index:datasets')/xpml"/>
<xsl:variable name="mime_types" select="document('arg:mime_types')/mime_types"/>
<xsl:variable name="docindex_datasets">
  <resource name="create">
    <title><xsl:value-of select="$labels/tools/create_docindex"/></title>
    <ref>
      <field required="yes" use-name="title"><name>title</name><label><xsl:value-of select="$labels/tools/docindex_title"/></label><type>tinytext</type></field>
      <field required="yes" use-name="index" ref="index:datasets"><name>index</name><label><xsl:value-of select="$labels/tools/docindex_datasource"/></label><type>ref-value</type></field>
      <field required="yes" use-name="template" ref="index:uris"><name>template</name><label><xsl:value-of select="$labels/tools/docindex_template"/></label><type>ref-value</type></field>
    </ref>
  </resource>
</xsl:variable>
<xsl:variable name="docindex_dataset"><xsl:if test="$request/get/index != ''"><xsl:copy-of select="document($request/get/index)/*"/></xsl:if></xsl:variable>
<xsl:variable name="docindex_template"><xsl:if test="contains($request/get/template, '#')"><xsl:copy-of select="document(substring-after($request/get/template, '#'))/xpml"/></xsl:if></xsl:variable>
<xsl:variable name="custom-datasets"><xsl:copy-of select="document('index:datasets')/xpml/resource[@type='component-structure' and contains(@meta-types, $docindex_template/xpml/meta/type)]"/></xsl:variable>


<xsl:template match="/">
<html>
  <head>
    <xsl:apply-templates select="$meta/*" mode="header"/>
    <link rel="stylesheet" href="{$base}/dav/styles/calendar-blue.css" type="text/css" />
    <link rel="stylesheet" href="{$base}/dav/styles/htmlarea.css" type="text/css" />
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/calendar.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/htmlarea.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/{$language}.js"><xsl:text> </xsl:text></script>
  </head>
  <body>
  <xsl:call-template name="header"/>
  <xsl:if test="normalize-space($msg) != ''"><div class="msg"><p><xsl:value-of select="$msg" disable-output-escaping="yes" /></p></div></xsl:if>
    <xsl:choose>
      <xsl:when test="$request/get/index != ''">
      <div id="col123">
        <table cellpadding="0" cellspacing="0" border="0" width="100%">
          <tbody>
          <tr>
            <td width="33%" class="first">
              <br />
            </td>
            <td width="67%" class="first" colspan="2">
              <h2><xsl:value-of select="$title"/></h2>
              <p>exp</p>
            </td>
          </tr>
          <tr>
            <xsl:variable name="fields"><field><name>@id</name><label>Document #id</label></field><field><name>@rid</name><label>Record #id</label></field><xsl:copy-of select="$docindex_dataset//field"/></xsl:variable>
            <td class="first">
              <xsl:for-each select="$fields/field[position() &lt;= (count($fields/field) div 3)]">
                <div><span style="width: 50px;">[[<xsl:value-of select="name"/>]]</span> &#151; <xsl:value-of select="label"/></div>
              </xsl:for-each>
            </td>
            <td class="first">
              <xsl:for-each select="$fields/field[position() &lt;= (count($fields/field) * 2 div 3) and  position() &gt; (count($fields/field) div 3)]">
                <div><span style="width: 50px;">[[<xsl:value-of select="name"/>]]</span> &#151; <xsl:value-of select="label"/></div>
              </xsl:for-each>
            </td>
            <td class="first">
              <xsl:for-each select="$fields/field[position() &gt; (count($fields/field) * 2 div 3)]">
                <div><span style="width: 50px;">[[<xsl:value-of select="name"/>]]</span> &#151; <xsl:value-of select="label"/></div>
              </xsl:for-each>
            </td>
          </tr>
          </tbody>
        </table>
        <br /><br />
        <table cellpadding="0" cellspacing="0" border="0" width="100%">
          <tbody>
          <tr>
            <td width="33%" class="first">
              <xsl:apply-templates select="$docindex_template/xpml/meta"/>
            </td>
            <td width="67%" class="first">
              <div class="dataset">
              <xsl:apply-templates select="$docindex_template/xpml/resource" mode="content"/>
              </div>
              <textarea class="textinput" rows="10"><xsl:copy-of select="$docindex_template"/></textarea>
            </td>
          </tr>
          </tbody>
        </table>
      </div>
      <div class="invisible">
        <xsl:apply-templates select="$docindex_template/xpml/meta" mode="meta-hidden"/>
      </div>
      </xsl:when>
      <xsl:otherwise>
        <div id="col2">
        <h1><xsl:value-of select="$title"/></h1>
        <form name="dav" submit-encoding="iso-8859-1" method="get" action="{$script-name}" enctype="multipart/form-data">
          <h3><xsl:value-of select="$docindex_datasets/resource[@name='create']/title"/></h3>
          <xsl:apply-templates select="$docindex_datasets/resource[@name='create']/ref" mode="dataset-editing">
            <xsl:with-param name="e" select="name"/>
          </xsl:apply-templates>
          <input class="submitinput" type="submit" value=" {$labels/buttons/select} " accesskey="s" />
        </form>
        </div>
      </xsl:otherwise>
    </xsl:choose>
  </body>
</html>
</xsl:template>

<xsl:template match="resource" mode="content">
  <xsl:param name="position" select="count(preceding-sibling::resource) + 1"/>
  <xsl:variable name="e" select="concat('x[', $position, '][resource]')"/>
  <xsl:variable name="id" select="concat(substring-before(@id, '#'), '#', $position)"/>
  <xsl:variable name="ref" select="."/>
  <div id="{$position}" name="{$position}" class="content">
    <p>
      <xsl:value-of select="$position"/>: <xsl:value-of select="$custom-datasets/resource[@name=current()/@type and @type='component-structure']/title"/>
      <xsl:if test="$position &gt; 1 and not(normalize-space($read-only)= 'all') and not(contains($read-only, 'resource-content '))"><xsl:text> </xsl:text><a href="#" style="text-decoration: none;" onclick="pin_swap_position('{$position}', '{$position -1}');"><img src="{$base}/dav/images/goup.gif" width="15" height="18" alt="{$labels/content/goup}" border="0" style="vertical-align: middle;" /></a></xsl:if>
      <xsl:if test="not(contains($read-only, 'resource-content ')) and not(normalize-space($read-only)= 'all')">
      <xsl:text>&#160;</xsl:text><a href="#" onclick="pin_todo.action='delete';pin_todo.param='{$e}';pin_send(document.dav);"><img src="{$base}/dav/images/delete.gif" width="10" height="10" alt="{$labels/content/delete}" border="0" style="vertical-align: middle;" /></a>
      </xsl:if>
      <input type="hidden" name="{$e}[@type]" value="{@type}"/>
      <input type="hidden" name="{$e}[@id]" value="{$id}"/>
    </p>
    <xsl:apply-templates select="$custom-datasets/resource[@name=current()/@type and @type='component-structure']/ref" mode="dataset-editing">
      <xsl:with-param name="ref" select="$ref"/>
      <xsl:with-param name="e" select="$e"/>
      <xsl:with-param name="pos" select="$position"/>
    </xsl:apply-templates>
  </div>
  <br />
</xsl:template>

</xsl:stylesheet>