<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml" omit-xml-declaration="yes"/>

<xsl:param name="auth-user"/>
<xsl:param name="title"/>
<xsl:param name="docindex_index"/>
<xsl:param name="docindex_title"/>
<xsl:param name="docindex_active"/>
<xsl:param name="docindex_overwrite"/>

<xsl:include href="dav_header.xsl"/>
<xsl:include href="dav_meta.xsl"/>
<xsl:include href="dav_components.xsl"/>

<xsl:variable name="meta">
  <meta>
  <title><xsl:value-of select="$title"/></title>
  </meta>
</xsl:variable>
<xsl:variable name="datasets" select="document('index:datasets')/xpml"/>
<xsl:variable name="mime_types" select="document('arg:mime_types')/mime_types"/>
<xsl:variable name="docindex_dataset"><xsl:copy-of select="document('arg:docindex_datasets')/*"/></xsl:variable>
<xsl:variable name="docindex_template"><xsl:copy-of select="document('arg:docindex_template')/xpml"/></xsl:variable>
<xsl:variable name="custom-datasets"><xsl:copy-of select="document('index:datasets')/xpml/resource[@type='dataset-structure']"/></xsl:variable>
<xsl:variable name="di" select="document('arg:di')/xpml"/>
<xsl:variable name="docindex_datasets">
  <resource name="create">
    <title><xsl:value-of select="$labels/tools/create_docindex"/></title>
    <ref>
      <field required="yes" use-name="title"><name>title</name><label><xsl:value-of select="$labels/tools/docindex_title"/></label><type>tinytext</type></field>
      <field required="yes" use-name="index"><name>index</name><label><xsl:value-of select="$labels/tools/docindex_datasource"/></label><type>set</type>
        <select>
          <xsl:for-each select="$custom-datasets/resource">
            <ref id="{@ref}"><xsl:value-of select="title"/></ref>
          </xsl:for-each>
        </select>
      </field>
      <field required="yes" use-name="template" ref="index:uris"><name>template</name><label><xsl:value-of select="$labels/tools/docindex_template"/></label><type>ref-value</type></field>
    </ref>
  </resource>
  <resource name="options">
    <title><xsl:value-of select="$labels/tools/edit_docindex"/></title>
    <ref>
      <field required="yes" use-name="title"><name>title</name><label><xsl:value-of select="$labels/tools/docindex_title"/></label><type>tinytext</type><value><xsl:value-of select="$docindex_title"/></value></field>
      <field required="no" use-name="active"><name>active</name><label><xsl:value-of select="$labels/tools/docindex_active"/></label><type>boolean</type><value><xsl:value-of select="$docindex_active"/></value></field>
      <field required="no" use-name="overwrite"><name>overwrite</name><label><xsl:value-of select="$labels/tools/docindex_overwrite"/></label><type>boolean</type><value><xsl:value-of select="$docindex_overwrite"/></value></field>
      <field required="yes" use-name="template" ref="index:uris"><name>template</name><label><xsl:value-of select="$labels/tools/docindex_template"/></label><type>ref-value</type></field>
    </ref>
  </resource>
</xsl:variable>

<xsl:template match="/">
<html>
  <head>
    <xsl:apply-templates select="$meta/*" mode="header"/>
    <link rel="stylesheet" href="{$base}/dav/styles/calendar-blue.css" type="text/css" />
    <link rel="stylesheet" href="{$base}/dav/styles/htmlarea.css" type="text/css" />
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/calendar.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/htmlarea.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" charset="iso-8859-1" src="{$base}/dav/scripts/{$language}.js"><xsl:text> </xsl:text></script>
  </head>
  <body>
  <xsl:call-template name="header"/>
  <xsl:if test="normalize-space($msg) != ''"><div class="msg"><p><xsl:value-of select="$msg" disable-output-escaping="yes" /></p></div></xsl:if>
    <xsl:choose>
      <xsl:when test="$docindex_dataset != '' and $request/get/docindex != ''">
        <xsl:choose>
          <xsl:when test="$request/get/edit = 'pages'">
            <div id="col23">
            <h1><xsl:value-of select="$title"/></h1>
            <form name="dav" submit-encoding="iso-8859-1" method="post" action="{$request-uri}" enctype="multipart/form-data">
              <h3><xsl:value-of select="$labels/tools/docindex_pages"/></h3>
              <table cellpadding="0" cellspacing="0" border="0">
                <tbody>
                  <tr>
                    <th class="first">URL</th><th><xsl:value-of select="$labels/meta/date"/></th>
                  </tr>
                  <xsl:for-each select="document('arg:docindex_pages')/xpml/url">
                    <xsl:variable name="tmpurl" select="."/>
                    <tr onMouseOver="this.bgColor='#ccddcd';" onMouseOut="this.bgColor='#fafffe';" class="tablerow">
                      <xsl:choose>
                        <xsl:when test="$uris//uri[. = $tmpurl]">
                          <td class="first"><a href="{$tmpurl}"><xsl:value-of select="$tmpurl"/></a></td>
                          <td><xsl:apply-templates mode="diff-date" select="document($uris//uri[. = $tmpurl]/@id)/xpml/meta/date[@type='modified']"/></td>
                          <td><a href="{$base}/edit.dav?id={$docindex_index}&amp;ref={@id}"><img src="{$base}/dav/images/dav_edit.gif" width="11" height="11" alt="{$labels/buttons/edit}" border="0" /></a></td>
                        </xsl:when>
                        <xsl:otherwise>
                          <td class="first"><span class="undef"><xsl:value-of select="$tmpurl"/></span></td>
                          <td colspan="2"><span class="undef"><xsl:value-of select="$labels/tools/unavailable"/></span></td>
                        </xsl:otherwise>
                      </xsl:choose>
                    </tr>
                  </xsl:for-each>
                </tbody>
              </table>
              <br />
              <br />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}';" value=" {$labels/tools/view_template} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=options';" value=" {$labels/tools/view_options} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=pages&amp;update=1';" value=" {$labels/tools/update_pages} " />
              <input class="submitinput" type="button" onclick="if(confirm('{$labels/tools/docindex_confirm_delete}')) window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;delete=1'; else return false;" value=" {$labels/buttons/delete} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}'" value=" {$labels/buttons/close} " />
            </form>
            </div>
          </xsl:when>
          <xsl:when test="$request/get/edit = 'options'">
            <div id="col23">
            <h1><xsl:value-of select="$title"/></h1>
            <form name="dav" submit-encoding="iso-8859-1" method="post" action="{$request-uri}" enctype="multipart/form-data">
              <h3><xsl:value-of select="$docindex_datasets/resource[@name='options']/title"/></h3>
              <div style="width:50%"><xsl:apply-templates select="$docindex_datasets/resource[@name='options']/ref" mode="dataset-editing">
                <xsl:with-param name="e" select="name"/>
              </xsl:apply-templates>
              </div>
              <input class="submitinput" type="button" onclick="pin_send(document.dav);" value=" {$labels/buttons/save} " accesskey="s" />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}';" value=" {$labels/tools/view_template} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=pages';" value=" {$labels/tools/view_pages} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=pages&amp;update=1';" value=" {$labels/tools/update_pages} " />
              <input class="submitinput" type="button" onclick="if(confirm('{$labels/tools/docindex_confirm_delete}')) window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;delete=1'; else return false;" value=" {$labels/buttons/delete} " />
              <input class="submitinput" type="button" onclick="window.location.href='{$script-name}'" value=" {$labels/buttons/close} " />
            </form>
            </div>
          </xsl:when>
          <xsl:otherwise>
          <div id="col123">
            <form name="dav" submit-encoding="iso-8859-1" method="post" action="{$script-name}?docindex={$request/get/docindex}" enctype="multipart/form-data">
              <input type="hidden" name="index" id="index" value="{$request/get/index}"/>
              <table cellpadding="0" cellspacing="0" border="0" width="100%">
                <tbody>
                <tr>
                  <xsl:variable name="fields"><field><name>@id</name><label>Document #id</label></field><field><name>@rid</name><label>Record #id</label></field><field><name>@date-created</name><label><xsl:value-of select="$labels/meta/date"/></label></field><field><name>@date-modified</name><label><xsl:value-of select="$labels/meta/date_modified"/></label></field><xsl:copy-of select="$docindex_dataset//field"/></xsl:variable>
                  <td width="33%" class="first">
                    <table cellpadding="0" cellspacing="0" border="0">
                      <tbody>
                        <tr>
                        <th class="first"><xsl:value-of select="$labels/tools/key"/></th>
                        <th><xsl:value-of select="$labels/tools/label"/></th>
                        </tr>
                        <xsl:for-each select="$fields/field">
                          <tr><td class="first">[[<xsl:value-of select="name"/>]]</td><td><xsl:value-of select="label"/></td></tr>
                        </xsl:for-each>
                      </tbody>
                    </table>
                  </td>
                  <td width="67%" class="first">
                    <h2><xsl:value-of select="$title"/></h2>
                    <p><xsl:value-of select="$labels/tools/docindex_description" disable-output-escaping="yes"/></p>
                    <div class="ixml">
                    <xsl:apply-templates select="$docindex_template/xpml" mode="xml-edit"/>
                    </div>
                    <br />
                    <input class="submitinput" type="button" onclick="pin_send(document.dav);" value=" {$labels/buttons/save} " accesskey="s" />
                    <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=options';" value=" {$labels/tools/view_options} " />
                    <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=pages';" value=" {$labels/tools/view_pages} " />
                    <input class="submitinput" type="button" onclick="window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;edit=pages&amp;update=1';" value=" {$labels/tools/update_pages} " />
                    <input class="submitinput" type="button" onclick="if(confirm('{$labels/tools/docindex_confirm_delete}')) window.location.href='{$script-name}?docindex={$request/get/docindex}&amp;delete=1'; else return false;" value=" {$labels/buttons/delete} " />
                    <input class="submitinput" type="button" onclick="window.location.href='{$script-name}'" value=" {$labels/buttons/close} " />
                  </td>
                </tr>
                </tbody>
              </table>
            </form>
          </div>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <div id="col2">
          <h1><xsl:value-of select="$title"/></h1>
          <form name="dav" submit-encoding="iso-8859-1" method="post" action="{$script-name}" enctype="multipart/form-data">
            <h3><xsl:value-of select="$docindex_datasets/resource[@name='create']/title"/></h3>
            <xsl:apply-templates select="$docindex_datasets/resource[@name='create']/ref" mode="dataset-editing">
              <xsl:with-param name="e" select="name"/>
            </xsl:apply-templates>
            <input class="submitinput" type="button" onclick="pin_send(document.dav);" value=" {$labels/buttons/create} " accesskey="s" />
          </form>
          <p><strong><xsl:value-of select="$labels/tools/docindex_listing"/></strong></p>
          <xsl:for-each select="$di/ref">
            <p><a href="{$script-name}?docindex={@id}"><xsl:value-of select="."/></a></p>
          </xsl:for-each>
          <xsl:if test="count($di/ref) = 0"><p><xsl:value-of select="$labels/tools/docindex_norecords"/></p></xsl:if>
        </div>
      </xsl:otherwise>
    </xsl:choose>
  </body>
</html>
</xsl:template>

<xsl:template match="*" mode="xml-edit">
  <xsl:param name="element" select="'ixml'"/>
  <xsl:variable name="el" select="concat($element, '[', position() -1, '][', name(), ']')"/>
  <div>
    <span class="ixml">&lt;<label for="{$el}[]"><xsl:value-of select="name()"/></label></span>
    <xsl:for-each select="@*">
      <xsl:text>&#160;&#160;</xsl:text>
      <label for="{$el}[@{name()}]"><xsl:value-of select="name()"/></label>
      <xsl:text>=</xsl:text>
      <xsl:choose>
        <xsl:when test="$el != 'ixml[0][xpml]' and name() != 'type' and name() != 'id'">
          <input type="text" name="{$el}[@{name()}]" value="{.}" />
        </xsl:when>
        <xsl:otherwise>
          <span class="text">"<xsl:value-of select='.'/>"</span>
          <input type="hidden" name="{$el}[@{name()}]" value="{.}" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
    <span class="ixml">&gt;</span>
    <xsl:choose>
      <xsl:when test="*">
        <xsl:apply-templates mode="xml-edit" select="*">
          <xsl:with-param name="element" select="$el"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates mode="xml-edit" select="text()">
          <xsl:with-param name="element" select="$el"/>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
    <span class="ixml">&lt;/<strong><xsl:value-of select="name()"/></strong>&gt;</span>
  </div>
</xsl:template>

<xsl:template match="text()" mode="xml-edit">
  <xsl:param name="element" select="'ixml'"/>
  <xsl:variable name="el" select="concat($element, '[]')"/>
  <xsl:choose>
    <xsl:when test="ancestor::date[not(@type='issued')] and ancestor::meta">
      <span class="text">[[@date-<xsl:value-of select="ancestor::date/@type"/>]]</span>
      <input type="hidden" name="{$el}" value="[[@date-{ancestor::date/@type}]]" />
    </xsl:when>
    <xsl:when test="ancestor::identifier[@type='id'] or (ancestor::type and ancestor::meta) or (ancestor::format and ancestor::meta) or (ancestor::date[not(@type='issued')] and ancestor::meta)">
      <span class="text"><xsl:value-of select='.'/></span>
      <input type="hidden" name="{$el}" value="{.}" />
    </xsl:when>
    <xsl:when test="string-length(.) &gt; 200">
      <div>
      <textarea id="{$el}" name="{$el}" rows="4">
        <xsl:value-of select="."/>
      </textarea>
      </div>
    </xsl:when>
    <xsl:otherwise>
      <input type="text" name="{$el}" value="{.}" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="*" mode="diff-date">
  <xsl:param name="date" select="$date"/>
<xsl:if test="substring(., 1, 10) != substring($date, 1, 10)"><xsl:value-of select="substring(., 1, 10)"/>&#160;</xsl:if>
<xsl:value-of select="substring(., 12, 5)"/>
</xsl:template>

</xsl:stylesheet>