<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="no" method="xml" omit-xml-declaration="no"/>

<xsl:param name="date"/>
<xsl:param name="update-rights"/>
<xsl:variable name="index_update" select="document('arg:index_update')"/>
<xsl:variable name="request" select="document('arg:request')/request"/>
<xsl:variable name="post"><xsl:if test="count($index_update/*/*) = 0"><xsl:copy-of select="$request/post/*"/></xsl:if></xsl:variable>
<xsl:variable name="defaults" select="document('arg:defaults')/defaults"/>
<xsl:variable name="xpml" select="/xpml"/>
<xsl:param name="xpml-identifier" select="/xpml/meta/identifier[@type='id']"/>
<xsl:include href="dav_meta_update.xsl"/>
<xsl:include href="components_update.xsl"/>

<xsl:template match="/"><xsl:apply-templates/></xsl:template>

<xsl:template match="resource" priority="1">
  <xsl:choose>
    <xsl:when test="current()/@name = $index_update/resource/@name">
      <xsl:variable name="name" select="@name"/>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates select="*[not(.//@id = $index_update/resource/*/@id)]|text()|processing-instruction()|comment()"/>
        <xsl:apply-templates select="$index_update/resource/*[@id != current()/descendant::*/@id]" mode="copy"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="*[@id]">
  <xsl:variable name="name" select="name()"/>
  <xsl:choose>
    <xsl:when test="current()/@id = $index_update/resource/*/@id">
      <xsl:if test="not(preceding-sibling::*[@id = current()/@id] and normalize-space($index_update/resource/*[@id = current()/@id]) != '')">
        <xsl:apply-templates select="$index_update/resource/*[@id = current()/@id]" mode="copy"/>
      </xsl:if>
    </xsl:when>
    <xsl:when test="$index_update/ref[substring-after(@id, concat($xpml-identifier, '#')) = current()/@id and current()/@id != '']">
      <xsl:if test="not(preceding-sibling::*[@id = current()/@id])">
        <xsl:for-each select="$index_update/ref[substring-after(@id, concat($xpml-identifier, '#')) = current()/@id][normalize-space(.) != ''][1]">
          <xsl:element name="{$name}">
            <xsl:attribute name="id"><xsl:value-of select="substring-after(@id, concat($xpml-identifier, '#'))"/></xsl:attribute>
            <xsl:apply-templates select="@*[name() != 'id']"/>
            <xsl:apply-templates/>
          </xsl:element>
        </xsl:for-each>
      </xsl:if>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- sitemap -->
<xsl:template match="resource[@name='sitemap']/root">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:if test="$index_update/page/ref = 'root' and $index_update/page/ref-type = 'following-sibling'">
      <page ref="{$index_update/page/@ref}">
        <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $index_update/page/@ref]/*"/>
      </page>
    </xsl:if>
    <xsl:apply-templates select="page"/>
    <xsl:if test="$index_update/page/ref = 'root' and ($index_update/page/ref-type = 'ancestor' or $index_update/page/ref-type = 'preceding-sibling')">
      <page ref="{$index_update/page/@ref}">
        <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $index_update/page/@ref]/*"/>
      </page>
    </xsl:if>
  </xsl:element>
</xsl:template>

<xsl:template match="resource[@name='sitemap']//page">
  <xsl:choose>
    <xsl:when test="not(@ref = $index_update/page/@ref)">
      <xsl:if test="$index_update/page/ref = current()/@ref and $index_update/page/ref-type = 'following-sibling'">
        <page ref="{$index_update/page/@ref}">
          <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $index_update/page/@ref]/*"/>
        </page>
      </xsl:if>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates select="page"/>
        <xsl:if test="$index_update/page/ref = current()/@ref and $index_update/page/ref-type = 'ancestor'">
          <page ref="{$index_update/page/@ref}">
            <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $index_update/page/@ref]/*"/>
          </page>
        </xsl:if>
      </xsl:element>
      <xsl:if test="$index_update/page/ref = current()/@ref and $index_update/page/ref-type = 'preceding-sibling'">
        <page ref="{$index_update/page/@ref}">
          <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $index_update/page/@ref]/*"/>
        </page>
      </xsl:if>
    </xsl:when>
  </xsl:choose>
</xsl:template>
<!-- fim do sitemap -->

<xsl:template match="resource[@type='dataset']" priority="1">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:variable name="name" select="@name"/>
    <xsl:apply-templates />
    <xsl:if test="$index_update/ref[substring-after(@id, $xpml-identifier) = '#new_record']">
      <xsl:variable name="next" select="@next"/>
      <xsl:for-each select="$index_update/ref[substring-after(@id, $xpml-identifier) = '#new_record'][1]">
        <xsl:element name="ref">
          <xsl:attribute name="id"><xsl:value-of select="$next"/></xsl:attribute>
          <xsl:apply-templates select="@*[name() != 'id']"/>
          <xsl:apply-templates/>
        </xsl:element>
      </xsl:for-each>
    </xsl:if>
  </xsl:element>
</xsl:template>

<xsl:template match="resource[@type='dataset']/@next">
  <xsl:choose>
    <xsl:when test="$index_update/ref[substring-after(@id, $xpml-identifier) = '#new_record']">
      <xsl:attribute name="{name()}"><xsl:value-of select=". +1"/></xsl:attribute>
    </xsl:when>
    <xsl:otherwise><xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute></xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="xpml" priority="1">
<xpml version="0.1">
  <xsl:apply-templates select="@*[name() != 'version']"/>
  <xsl:apply-templates/>
</xpml>
</xsl:template>

<xsl:template match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="pre-copy" match="*">
  <xsl:apply-templates mode="copy"/>
</xsl:template>

<xsl:template match="text()" mode="pre-copy">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="@*">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template mode="copy" match="*">
  <xsl:if test=". != ''">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates mode="copy"/>
    </xsl:element>
  </xsl:if>
</xsl:template>

<xsl:template mode="copy" match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

</xsl:stylesheet>