<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="yes" method="xml" omit-xml-declaration="no"/>

<xsl:param name="date"/>
<xsl:param name="password-update"/>
<xsl:param name="edit-action"/>
<xsl:variable name="update" select="document('arg:update')"/>
<xsl:variable name="user" select="$update/user/login[1]"/>

<xsl:template match="/"><xsl:apply-templates/></xsl:template>

<xsl:template match="*">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="xpml" priority="1">
<xpml version="0.1">
  <xsl:apply-templates select="@*[name() != 'version']"/>
  <xsl:apply-templates/>
</xpml>
</xsl:template>

<xsl:template match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="pre-copy" match="*">
  <xsl:apply-templates mode="copy"/>
</xsl:template>

<xsl:template match="@*">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template mode="copy" match="*">
  <xsl:if test=". != ''">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates mode="copy"/>
    </xsl:element>
  </xsl:if>
</xsl:template>

<xsl:template mode="copy" match="text()">
  <xsl:value-of select="normalize-space(.)"/>
</xsl:template>

<xsl:template mode="copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="/xpml/meta/date[@type='modified']">
  <date type="modified"><xsl:value-of select="$date"/></date>
</xsl:template>

<xsl:template match="user">
  <xsl:param name="ignore-action"/>
  <xsl:choose>
    <xsl:when test="(login = $user and string($edit-action) = '') or $ignore-action = 1">
      <user id="{$user}">
        <xsl:apply-templates select="$update/user/@*[name() != 'id']"/>
        <login><xsl:value-of select="$user"/></login>
        <xsl:for-each select="$update/user/*[not(name() = 'password') and not(name() = 'login')]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <xsl:if test="not($update/user/*[not(name() = 'password') and not(name() = 'login')])">
          <xsl:apply-templates mode="copy" select="*[not(name() = 'password') and not(name() = 'login')]"/>
        </xsl:if>
        <password>
          <xsl:choose>
            <xsl:when test="$password-update != ''"><xsl:value-of select="$password-update"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="password"/></xsl:otherwise>
          </xsl:choose>
        </password>
      </user>
    </xsl:when>
    <xsl:when test="$edit-action = 'delete' and login = $user">
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates mode="copy" select="."/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="resource[@name='users']">
<xsl:element name="{name()}">
<xsl:apply-templates select="@*" />
<xsl:apply-templates />
<xsl:if test="$edit-action = 'new' and not($update/user[1]/login = current()/user/login)">
  <xsl:apply-templates select="$update/user[1]">
    <xsl:with-param name="ignore-action" select="1"/>
  </xsl:apply-templates>
</xsl:if>
</xsl:element>
</xsl:template>
</xsl:stylesheet>