<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="yes" method="xml" omit-xml-declaration="no"/>

<xsl:param name="date"/>
<xsl:param name="edit-action"/>
<xsl:variable name="update" select="document('arg:update')/cvs"/>
<xsl:variable name="xpml"><xsl:copy-of select="/xpml"/></xsl:variable>

<xsl:template match="/"><xsl:apply-templates/></xsl:template>

<xsl:template match="*">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="xpml" priority="1">
<xpml version="0.1">
  <xsl:apply-templates select="@*[name() != 'version']"/>
  <xsl:apply-templates/>
</xpml>
</xsl:template>

<xsl:template match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="normalize-space(.)"/>
</xsl:template>

<xsl:template mode="pre-copy" match="*">
  <xsl:apply-templates mode="copy"/>
</xsl:template>

<xsl:template match="@*">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template mode="copy" match="*">
  <xsl:if test=". != ''">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates mode="copy"/>
    </xsl:element>
  </xsl:if>
</xsl:template>

<xsl:template mode="copy" match="text()">
  <xsl:value-of select="normalize-space(.)"/>
</xsl:template>

<xsl:template mode="copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="/xpml/meta/date[@type='modified']">
  <date type="modified"><xsl:value-of select="$date"/></date>
</xsl:template>

<!--
    <user id="admin">
      <login>admin</login>
      <name>Administrator</name>
      <email>admin@capile.net</email>
      <wysiwyg-editor>yes</wysiwyg-editor>
      <password>$1$t.1.yN/.$lTzXclWSJthw8EE.jptee1</password>
    </user>
-->
<xsl:template match="user">
  <xsl:param name="ignore-action"/>
  <xsl:variable name="login" select="login"/>
  <xsl:choose>
    <xsl:when test="$edit-action = 'edit-user' and ($login = $update/line/login) and $login != 'admin'">
      <xsl:apply-templates select="$update/line[login = $login]" mode="cvs">
        <xsl:with-param name="password" select="password"/>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="$edit-action = 'delete-user' and ($login = $update/line/login) and $login != 'admin'">
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates mode="copy" select="."/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="line" mode="cvs">
  <xsl:param name="password" select="document('php:xml_crypt:teste')/*"/>
  <user id="{login}">
    <login><xsl:value-of select="login"/></login>
    <xsl:apply-templates select="name|email|wysiwyg-editor"/>
    <password>
      <xsl:choose>
        <xsl:when test="normalize-space(password) != ''"><xsl:value-of select="document(concat('php:xml_crypt:', password))/*"/></xsl:when>
        <xsl:otherwise><xsl:value-of select="password"/></xsl:otherwise>
      </xsl:choose>
    </password>
  </user>
</xsl:template>

<xsl:template match="wysiwyg-editor">
<xsl:if test=". = 1 or . = 'yes'">
  <xsl:element name="{name()}">yes</xsl:element>
</xsl:if>
</xsl:template>

<xsl:template match="resource[@name='users']">
<xsl:element name="{name()}">
<xsl:apply-templates select="@*" />
<xsl:apply-templates />
<xsl:if test="$edit-action = 'edit-user'">
  <xsl:for-each select="$update/line">
    <xsl:variable name="login" select="login"/>
    <xsl:if test="not($xpml//user/login = $login)">
      <xsl:apply-templates select="." mode="cvs"/>
    </xsl:if>
  </xsl:for-each>
</xsl:if>
</xsl:element>
</xsl:template>
</xsl:stylesheet>