<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xsd">
<xsl:output encoding="iso-8859-1" indent="no" method="xml" omit-xml-declaration="no"/>

<xsl:param name="date"/>

<xsl:variable name="index_update" select="document('arg:index_update')"/>

<xsl:template match="/"><xsl:apply-templates/></xsl:template>

<xsl:template match="*">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="resource">
  <xsl:choose>
    <xsl:when test="current()/@name = $index_update/resource/@name and not(current()/descendant::*/@id = $index_update/resource/*/@id)">
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
        <xsl:apply-templates select="$index_update/resource/*[@id != current()/descendant::*/@id]" mode="copy"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="*[@id]">
  <xsl:choose>
    <xsl:when test="current()/@id = $index_update/resource/*/@id">
      <xsl:if test="not(preceding-sibling::*[@id = current()/@id])">
        <xsl:apply-templates select="$index_update/resource/*[@id = current()/@id]" mode="copy"/>
      </xsl:if>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- sitemap -->
<xsl:template match="resource[@name='sitemap']/root">aaaa
  <xsl:choose>
    <xsl:when test="$index_update/resource/*[1]/ancestor = 'root'">
      <xsl:variable name="child" select="$index_update/resource/*[1]"/>
      <xsl:element name="{name}">
        <xsl:apply-templates select="@*"/>
        <xsl:for-each select="page[not(@ref = $child/@ref)]">
          <xsl:if test="position() = $child/position">
            <page ref="{$child/@ref}">
              <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $child/@ref]/*"/>
            </page>
          </xsl:if>
          <page ref="{@ref}">
            <xsl:apply-templates/>
          </page>
        </xsl:for-each>
        <xsl:if test="number($child/position) &lt; 1 or number($child/position) &gt; count(pages[not(@ref = $child/@ref)])">
          <page ref="{$child/@ref}">
            <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $child/@ref]/*"/>
          </page>
        </xsl:if>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
<xsl:template match="resource[@name='sitemap']//page">
  <xsl:choose>
    <xsl:when test="current()/@ref = $index_update/resource/*[1]/ancestor">
      <xsl:variable name="child" select="$index_update/resource/*[1]"/>
      <xsl:element name="{name}">
        <xsl:apply-templates select="@*"/>
        <xsl:for-each select="page[not(@ref = $child/@ref)]">
          <xsl:if test="position() = $child/position">
            <page ref="{$child/@ref}">
              <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $child/@ref]/*"/>
            </page>
          </xsl:if>
          <page ref="{@ref}">
            <xsl:apply-templates/>
          </page>
        </xsl:for-each>
        <xsl:if test="number($child/position) &lt; 1 or number($child/position) &gt; count(pages[not(@ref = $child/@ref)])">
          <page ref="{$child/@ref}">
            <xsl:apply-templates select="//resource[@name='sitemap']//page[@ref = $child/@ref]/*"/>
          </page>
        </xsl:if>
      </xsl:element>
    </xsl:when>
    <xsl:when test="current()/@ref != $index_update/resource/*[1]/@ref]">
      <xsl:element name="{name()}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:when>
  </xsl:choose>
</xsl:template>
<!-- fim do sitemap -->

<xsl:template match="xpml" priority="1">
<xpml version="0.1">
  <xsl:apply-templates select="@*[name() != 'version']"/>
  <xsl:apply-templates/>
</xpml>
</xsl:template>

<xsl:template match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template mode="pre-copy" match="*">
  <xsl:apply-templates mode="copy"/>
</xsl:template>

<xsl:template match="@*">
  <xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
</xsl:template>

<xsl:template mode="copy" match="*">
  <xsl:if test=". != ''">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates mode="copy"/>
    </xsl:element>
  </xsl:if>
</xsl:template>

<xsl:template mode="copy" match="text()">
  <xsl:value-of select="normalize-space(.)"/>
</xsl:template>

<xsl:template mode="copy" match="comment()">
  <xsl:comment><xsl:value-of select="."/></xsl:comment>
</xsl:template>

</xsl:stylesheet>