<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="iso-8859-1" indent="no" method="xhtml" omit-xml-declaration="yes"/>

<xsl:variable name="lc">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="uc">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
<xsl:variable name="latin"> </xsl:variable>
<xsl:variable name="plain">_aaaaaeeeeiiiiooooouuuuc</xsl:variable>
<xsl:variable name="uris"    select="document('index:uris')/xpml/resource[@name='uris']"/>
<xsl:variable name="sitemap" select="document('index:sitemap')/xpml/resource[@name='sitemap']"/>
<xsl:include href="meta.xsl"/>
<xsl:param name="query-string"/>

<xsl:template match="/">
<html>
  <head>
    <xsl:apply-templates select="xpml/meta">
      <xsl:with-param name="style" select="'/site.css'"/>
    </xsl:apply-templates>
  </head>
  <body>
    <xsl:apply-templates select="$sitemap/root/page" mode="navbar"/>
    <xsl:apply-templates select="xpml/resource"/>
  </body>
</html>
</xsl:template>

<!-- navbars -->

<xsl:template match="*" mode="navbar">
  <xsl:for-each select="document(page/@ref)">
    <div>
      <a href="{meta/identifier[@type='url']}"><xsl:value-of select="title"/></a>
    </div>
  </xsl:for-each>
</xsl:template>


<!-- resources -->
<xsl:template match="resource">
  <xsl:param name="pos" select="position"/>
  <xsl:if test="not(preceding-sibling::resource[position=$pos])">
    <div class="{translate(translate($pos, $uc, $lc), $latin, $plain)}">
      <xsl:apply-templates select="../resource[position=$pos]" mode="content" />
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="resource[@type='content']" mode="content"><xsl:value-of select="content" disable-output-escaping="yes"/></xsl:template>

<xsl:template match="resource[@type='cross-reference']" mode="content">
<p>
  <a href="{$uris/*[@id = current()/ref]}"><xsl:value-of select="title" disable-output-escaping="yes"/></a>
  <xsl:if test="date-issued != ''"><br /><xsl:apply-templates select="date-issued" mode="date"/></xsl:if>
  <xsl:if test="description != ''"><br /><xsl:value-of select="description" disable-output-escaping="yes"/></xsl:if>
</p>
</xsl:template>

<xsl:template match="resource[@type='external-reference']" mode="content">
<p>
  <a href="{url}"><xsl:value-of select="title" disable-output-escaping="yes"/></a>
  <xsl:if test="date-issued != ''"><br /><xsl:apply-templates select="date-issued" mode="date"/></xsl:if>
  <xsl:if test="description != ''"><br /><xsl:value-of select="description" disable-output-escaping="yes"/></xsl:if>
</p>
</xsl:template>

<xsl:template match="*|text()" mode="date">
  <xsl:value-of select="substring(., 1, 10)"/>
</xsl:template>

<xsl:template match="*" mode="diff-date">
  <xsl:param name="date" select="$date"/>
  <xsl:if test="substring(., 1, 10) != substring($date, 1, 10)"><xsl:value-of select="substring(., 1, 10)"/>&#160;</xsl:if>
  <xsl:value-of select="substring(., 12, 5)"/>
</xsl:template>

</xsl:stylesheet>