<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:param name="script-name"/>
<xsl:param name="request-uri"/>
<xsl:param name="search-dir"/>
<xsl:param name="publishing"/>

<!-- stores some basic variables -->
<xsl:variable name="xpml" select="/xpml"/>
<xsl:variable name="id" select="/xpml/meta/identifier[@type='id']"/>
<xsl:variable name="sitemap" select="document('index:sitemap')/xpml/resource[@name='sitemap']"/>
<xsl:variable name="uris">
  <xsl:for-each select="document('index:uris')/xpml/resource[@name='uris']/uri">aa
    <uri id="{@id}">
      <xsl:choose>
        <xsl:when test="contains(., '/index.')"><xsl:value-of select="substring-before(., '/index.')"/>/</xsl:when>
        <xsl:otherwise><xsl:value-of select="."/></xsl:otherwise>
      </xsl:choose>
    </uri>
  </xsl:for-each>
</xsl:variable>
<xsl:variable name="lc">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="uc">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
<xsl:variable name="latin"> $#@!"'+,\/.-()*%&amp;</xsl:variable>
<xsl:variable name="plain">_________________aaaaaeeeeiiiiooooouuuuc_amp_</xsl:variable>
<xsl:include href="form-component.xsl"/>
<xsl:include href="navbar.xsl"/>
<xsl:include href="header.xsl"/>

<xsl:template match="*|text()" mode="content"><xsl:value-of select="." disable-output-escaping="yes"/></xsl:template>

<xsl:template match="title[@type='alternative']"><h2><xsl:value-of select="." /></h2></xsl:template>

<xsl:template match="meta" mode="link">
  <a><xsl:if test="not(identifier[@type='id'] = $id)"><xsl:attribute name="href"><xsl:value-of select="concat(identifier[@type='url'])"/></xsl:attribute></xsl:if><xsl:value-of select="title"/></a>
</xsl:template>

<xsl:template match="resource">
  <div id="c{substring-after(@id, '#')}">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
  </div>
</xsl:template>

<xsl:template match="resource[@type='toc']">
  <div id="toc">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><!--<xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if>--></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <ul>
      <xsl:for-each select="../resource[@type != 'toc'][title != '']">
        <li><a href="#c{substring-after(@id, '#')}"><xsl:value-of select="title"/></a></li>
      </xsl:for-each>
    </ul>
    <br />
  </div>
</xsl:template>

<xsl:template match="resource[@type='search-results']" priority="1">
  <div id="c{substring-after(@id, '#')}" class="searchresults">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <xsl:if test="/xpml/meta/format = 'application/x-httpd-php'">
      <xsl:processing-instruction name="php">
        <xsl:text>global $sc; $sc = array(); $sc["index_dir"] = "</xsl:text><xsl:value-of select='$search-dir'/><xsl:text>";$sc["swish_dir"] = "</xsl:text><xsl:value-of select='$swish-dir'/><xsl:text>";</xsl:text>
        <xsl:for-each select="restrict[. != '']|exclude[. != '']">$sc["<xsl:value-of select='name()'/>"][]="<xsl:value-of select='.'/>"; </xsl:for-each>
        <xsl:for-each select="method[. != '']|words[. != '']|index[. != '']">$sc["<xsl:value-of select='name()'/>"]="<xsl:value-of select='.'/>"; </xsl:for-each>
        <xsl:for-each select="pre-results[. != '']|no-results[. != '']|results[. != '']">$sc["<xsl:value-of select='name()'/>"]=<xsl:text disable-output-escaping="yes">&lt;&lt;&lt;EOF
</xsl:text><xsl:value-of select='.' disable-output-escaping="yes"/><xsl:text>
EOF;
</xsl:text></xsl:for-each>
      </xsl:processing-instruction>
      <xsl:value-of select="document('include:search-component.php')/comment()" disable-output-escaping="yes"/>
      <xsl:processing-instruction name="php">if ($_GET["words"] != "" || $sc["words"] != "") { echo $sc["result"]; } else { echo $sc["pre-results"]; }</xsl:processing-instruction>
      <br />
    </xsl:if>
  </div>
</xsl:template>

<xsl:template match="resource[@type='cross-reference']">
  <div id="c{substring-after(@id, '#')}">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <xsl:if test="substring-after(ref/@ref, '#') != ''">
      <p>
        <xsl:for-each select="$sitemap/root//page[descendant::page/@ref = $uris/uri[text() = current()/ref]/@id]"><xsl:if test="position() &gt; 1"><xsl:for-each select="document(@ref)/xpml/meta"> &#187; <a href="{identifier[@type='url']}"><xsl:value-of select="title"/></a></xsl:for-each></xsl:if></xsl:for-each>
        <xsl:text> &#187; </xsl:text>
        <a href="{ref}"><xsl:value-of select="document(substring-after(ref/@ref, '#'))/xpml/meta/title[1]"/></a>
        <xsl:if test="date-issued">
          <span class="date"> &#151; <xsl:value-of select="date-issued"/></span>
        </xsl:if>
      </p>
    </xsl:if>
  </div>
</xsl:template>

<xsl:template match="resource[@type='external-reference']">
  <div id="c{substring-after(@id, '#')}">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <p>
      <xsl:text>&#187; </xsl:text>
      <a href="{url}"><xsl:value-of select="url"/></a>
      <xsl:if test="date-issued">
        <span class="date"> &#151; <xsl:value-of select="date-issued"/></span>
      </xsl:if>
    </p>
  </div>
</xsl:template>

<xsl:template match="resource[@type='component']">
  <xsl:variable name="component" select="document(include)/*/file/@ref-src"/>
  <div id="c{substring-after(@id, '#')}">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <xsl:if test="$component != ''">
      <xsl:copy-of select="document($component)" />
    </xsl:if>
  </div>
</xsl:template>

<xsl:template match="resource[@type='search-form']">
  <div class="searchform">
  <h2><label for="words"><xsl:value-of select="title"/></label></h2>
  <form action="{$uris/uri[@id = substring-after(current()/ref/@ref, '#')]}" name="searchform" method="get">
    <xsl:value-of select="content" disable-output-escaping="yes"/>
    <input class="textinput" type="text" name="words" id="words" value="" />
    <xsl:text> </xsl:text>
    <input class="submitinput" type="submit" value="Consultar" />
  </form>
  </div>
</xsl:template>

<xsl:template match="*|text()" mode="safe-php">
  <xsl:param name="str" select="."/>
  <xsl:value-of select="$str" disable-output-escaping="yes"/>
</xsl:template>

<xsl:template match="resource[@type='index-preview']">
  <xsl:variable name="dataset" select="document(dataset/@ref)/ref"/>
  <xsl:variable name="datafile" select="document(substring-after(dataset/@ref, '#'))/xpml"/>
  <div id="c{substring-after(@id, '#')}">
    <xsl:if test="position != ''"><xsl:attribute name="class"><xsl:value-of select="position"/></xsl:attribute></xsl:if>
    <xsl:if test="title != ''">
      <h2><xsl:value-of select="title"/><xsl:if test="../resource[@type='toc']"><a href="#toc"><img src="/_images/toc.gif" border="0" alt="Retornar ao topo" /></a></xsl:if></h2>
    </xsl:if>
    <xsl:value-of select="content" disable-output-escaping="yes" />
    <table cellpadding="0" cellspacing="0" border="0">
      <tbody>
        <tr class="tablerow">
          <xsl:for-each select="$dataset//field[@listing-display = 'yes']">
            <th>
              <xsl:if test="position() = 1"><xsl:attribute name="class">first</xsl:attribute></xsl:if>
              <xsl:value-of select="label"/>
            </th>
          </xsl:for-each>
        </tr>
        <xsl:for-each select="$datafile/resource/ref">
          <tr>
            <xsl:variable name="ref" select="."/>
            <xsl:for-each select="$dataset//field[@listing-display = 'yes']">
              <xsl:variable name="name" select="name"/>
              <td>
                <xsl:apply-templates mode="list" select="$ref/*[name() = current()/name]/text()|$ref/*[name() = current()/name]/*[1]/text()"/>
              </td>
            </xsl:for-each>
          </tr>
        </xsl:for-each>
      </tbody>
    </table>
  </div>
</xsl:template>

<xsl:template match="*" mode="date-day">
  <xsl:param name="s" select="'-'"/>
  <xsl:value-of select="concat(substring(., 9, 2), $s, substring(., 6, 2), $s, substring(., 1, 4))"/>
</xsl:template>

<xsl:template match="title[not(@type='alternative')]"><h1><img src="/_images/titles/h1/{substring-after($id, '_n')}.png" alt="{.}" border="0" /></h1></xsl:template>
<xsl:template match="title[not(@type='alternative')]"><h1><xsl:value-of select="."/></h1></xsl:template>
<xsl:template match="title[@type='alternative']"><h2><xsl:value-of select="." /></h2></xsl:template>

<xsl:template match="xpml" mode="content">
  <xsl:apply-templates select="resource[position = 'default']"/>
  <xsl:if test="resource[position = 'col1' or position = 'col2']">
    <div class="col1"><xsl:apply-templates select="resource[position = 'col1']"/><br /></div>
    <div class="col2"><xsl:apply-templates select="resource[position = 'col2']"/><br /></div>
  </xsl:if>
  <xsl:apply-templates select="resource[position = 'footer']"/>
</xsl:template>

<xsl:template match="xpml" mode="content">
  <xsl:apply-templates select="resource[position != 'footer']"/>
  <xsl:apply-templates select="resource[position = 'footer']"/>
</xsl:template>

<xsl:template match="resource" mode="boxes">
  <div class="ref">
    <h3><xsl:value-of select="title"/></h3>
    <xsl:apply-templates select="content"/>
  </div>
</xsl:template>

<xsl:template name="footer">
  <div class="footer">
   <p>Copyright  2004</p>
  </div>
</xsl:template>

</xsl:stylesheet>
