<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:variable name="xdb-enabled"><xsl:if test="$xpml/meta/format='application/x-httpd-php' and $xpml/resource/@type='xdb-function' or $xpml/resource/@type='xdb-permission'">1</xsl:if></xsl:variable>

<xsl:template name="xdb">
<xsl:if test="$xdb-enabled = 1">
  <xsl:apply-templates select="$xpml/resource[@type='xdb-function']|$xpml/resource[@type='xdb-permission']" mode="xdb-function"/>
</xsl:if>
</xsl:template>

<xsl:template match="resource[@type='xdb-function' or @type='xdb-permission']" mode="xdb-function">
  <xsl:processing-instruction name="php">
    <xsl:text disable-output-escaping="yes">
/************************************************************
 *                                                          *
 *      xdb configuration v. 0.1                            *
 *      Guilherme Capil &lt;atendimento@capile.net>           *
 *                                                          *
 ************************************************************/
global $xdbc, $xdb, $res, $err;</xsl:text>
    <xsl:if test="application != ''">
      <xsl:text>$xdb["application"] = "</xsl:text><xsl:value-of select='application'/><xsl:text>";</xsl:text>
    </xsl:if>
    <xsl:text>$xdb["body"] = ""; $xdb["page"]["access-rights"] = </xsl:text><xsl:apply-templates select="." mode="xdb-permission"/><xsl:text>;</xsl:text>
    <xsl:text>$xdbc["base"] = "</xsl:text><xsl:value-of select='$xdb-path'/><xsl:text disable-output-escaping='yes'>"; require_once($xdbc["base"]."/loader.php");$info["content"] = &lt;&lt;&lt;EOF
</xsl:text><xsl:if test="title != ''"><xsl:text disable-output-escaping="yes">&lt;h3></xsl:text><xsl:value-of select="title"/><xsl:text disable-output-escaping="yes">&lt;/h3></xsl:text></xsl:if><xsl:value-of select="content" disable-output-escaping="yes"/><xsl:text>
EOF;
</xsl:text><xsl:text disable-output-escaping='yes'>$info["content-error"] = &lt;&lt;&lt;EOF
</xsl:text><xsl:value-of select="content-error" disable-output-escaping="yes"/><xsl:text disable-output-escaping='yes'>
EOF;
$info["content-success"] = &lt;&lt;&lt;EOF
</xsl:text><xsl:value-of select="content-success" disable-output-escaping="yes"/><xsl:text>
EOF;
if (count($_POST) > 0) { $post = $_POST; }</xsl:text>
    <xsl:if test="table/@ref != ''">
      <xsl:text disable-output-escaping='yes'>$table = $xdbc["tables"]["</xsl:text><xsl:value-of select='document(table/@ref)/ref/table'/><xsl:text>"];</xsl:text>
    </xsl:if>
    <xsl:value-of select="pi" disable-output-escaping="yes"/>
    <xsl:if test="function/@ref != ''">
      <xsl:text disable-output-escaping='yes'>$xdb["body"] .= </xsl:text><xsl:value-of select="document(function/@ref)/ref/function"/><xsl:text>;</xsl:text>
    </xsl:if>
  </xsl:processing-instruction>
</xsl:template>

<xsl:template match="resource[@type='xdb-function']">
  <xsl:processing-instruction name="php">
    <xsl:text>echo xdb_template("pindorama");</xsl:text>
  </xsl:processing-instruction>
</xsl:template>

<xsl:template match="*" mode="xdb-permission">
    <!-- access-rights: controls whether the user has permissions to access this resource -->
    <xsl:choose>
      <xsl:when test="access-rights = 'true' or access-rights = 'false'">
        <xsl:value-of select="access-rights"/>
      </xsl:when>
      <xsl:when test="access-rights = 'user-group'">
        <xsl:text>array(</xsl:text>
        <xsl:if test="access-rights-users != ''">
          <xsl:text>"user"=>array(</xsl:text>
          <xsl:for-each select="access-rights-users[. != '']">
            <xsl:if test="position() != 1">,</xsl:if>
            <xsl:text>"</xsl:text><xsl:value-of select='.'/><xsl:text>"</xsl:text>
          </xsl:for-each>
          <xsl:text>)</xsl:text>
          <xsl:if test="access-rights-groups != ''">,</xsl:if>
        </xsl:if>
        <xsl:if test="access-rights-groups != ''">
          <xsl:text>"group"=>array(</xsl:text>
          <xsl:for-each select="access-rights-groups[. != '']">
            <xsl:if test="position() != 1">,</xsl:if>
            <xsl:text>"</xsl:text><xsl:value-of select="substring-after(., '#')" /><xsl:text>"</xsl:text>
          </xsl:for-each>
          <xsl:text>)</xsl:text>
        </xsl:if>
        <xsl:text>)</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>""</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="meta" mode="link" priority="1">
  <xsl:param name="class"/>
  <xsl:choose>
    <xsl:when test="not(identifier[@type='id'] = $id) and $xdb-enabled = 1 and ../resource[@type='xdb-function' or @type='xdb-permission']/access-rights != ''">
      <xsl:processing-instruction name="php"><xsl:text disable-output-escaping="yes">global $xdb, $xdbc; if (function_exists(xdb_permission) &amp;&amp; !xdb_permission(</xsl:text><xsl:apply-templates select="../resource[@type='xdb-function' or @type='xdb-permission'][1]" mode="xdb-permission"/><xsl:text>)) {</xsl:text></xsl:processing-instruction>
        <span id="forbid">
          <xsl:if test="$class != ''">
            <xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
          </xsl:if>
          <xsl:value-of select="title"/>
        </span>
      <xsl:processing-instruction name="php">} else {</xsl:processing-instruction>
        <a href="{$uris/uri[@id = current()/identifier[@type='id']]}">
          <xsl:if test="$class != ''">
            <xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
          </xsl:if>
          <xsl:value-of select="title"/>
        </a>
      <xsl:processing-instruction name="php">}</xsl:processing-instruction>
    </xsl:when>
    <xsl:otherwise>
      <!-- common result -->
      <xsl:choose>
        <xsl:when test="not(identifier[@type='id'] = $id)">
          <a href="{$uris/uri[@id = current()/identifier[@type='id']]}">
            <xsl:if test="$class != ''">
              <xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
            </xsl:if>
              <xsl:attribute name="href"><xsl:value-of select="$uris/uri[@id = current()/identifier[@type='id']]"/></xsl:attribute>
            <xsl:value-of select="title"/>
          </a>
        </xsl:when>
        <xsl:otherwise>
          <span>
            <xsl:if test="$class != ''">
              <xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
            </xsl:if>
            <xsl:value-of select="title"/>
          </span>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>